# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .abstract_field import AbstractField
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FunctionField(AbstractField):
    """
    Field outlining queryString aggregate function entries.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FunctionField object with values from keyword arguments. The default value of the :py:attr:`~oci.log_analytics.models.FunctionField.name` attribute
        of this class is ``FUNCTION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this FunctionField.
            Allowed values for this property are: "FIELD", "FIELDS", "FUNCTION", "SORT"
        :type name: str

        :param display_name:
            The value to assign to the display_name property of this FunctionField.
        :type display_name: str

        :param is_declared:
            The value to assign to the is_declared property of this FunctionField.
        :type is_declared: bool

        :param original_display_names:
            The value to assign to the original_display_names property of this FunctionField.
        :type original_display_names: list[str]

        :param internal_name:
            The value to assign to the internal_name property of this FunctionField.
        :type internal_name: str

        :param value_type:
            The value to assign to the value_type property of this FunctionField.
            Allowed values for this property are: "BOOLEAN", "STRING", "DOUBLE", "FLOAT", "LONG", "INTEGER", "TIMESTAMP", "FACET"
        :type value_type: str

        :param is_groupable:
            The value to assign to the is_groupable property of this FunctionField.
        :type is_groupable: bool

        :param is_duration:
            The value to assign to the is_duration property of this FunctionField.
        :type is_duration: bool

        :param alias:
            The value to assign to the alias property of this FunctionField.
        :type alias: str

        :param filter_query_string:
            The value to assign to the filter_query_string property of this FunctionField.
        :type filter_query_string: str

        :param function:
            The value to assign to the function property of this FunctionField.
        :type function: str

        :param arguments:
            The value to assign to the arguments property of this FunctionField.
        :type arguments: list[Argument]

        """
        self.swagger_types = {
            'name': 'str',
            'display_name': 'str',
            'is_declared': 'bool',
            'original_display_names': 'list[str]',
            'internal_name': 'str',
            'value_type': 'str',
            'is_groupable': 'bool',
            'is_duration': 'bool',
            'alias': 'str',
            'filter_query_string': 'str',
            'function': 'str',
            'arguments': 'list[Argument]'
        }

        self.attribute_map = {
            'name': 'name',
            'display_name': 'displayName',
            'is_declared': 'isDeclared',
            'original_display_names': 'originalDisplayNames',
            'internal_name': 'internalName',
            'value_type': 'valueType',
            'is_groupable': 'isGroupable',
            'is_duration': 'isDuration',
            'alias': 'alias',
            'filter_query_string': 'filterQueryString',
            'function': 'function',
            'arguments': 'arguments'
        }

        self._name = None
        self._display_name = None
        self._is_declared = None
        self._original_display_names = None
        self._internal_name = None
        self._value_type = None
        self._is_groupable = None
        self._is_duration = None
        self._alias = None
        self._filter_query_string = None
        self._function = None
        self._arguments = None
        self._name = 'FUNCTION'

    @property
    def function(self):
        """
        Gets the function of this FunctionField.
        Name of the aggregate function.


        :return: The function of this FunctionField.
        :rtype: str
        """
        return self._function

    @function.setter
    def function(self, function):
        """
        Sets the function of this FunctionField.
        Name of the aggregate function.


        :param function: The function of this FunctionField.
        :type: str
        """
        self._function = function

    @property
    def arguments(self):
        """
        Gets the arguments of this FunctionField.
        List of function arguments if specified.


        :return: The arguments of this FunctionField.
        :rtype: list[Argument]
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """
        Sets the arguments of this FunctionField.
        List of function arguments if specified.


        :param arguments: The arguments of this FunctionField.
        :type: list[Argument]
        """
        self._arguments = arguments

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateAttributeDetails(object):
    """
    Properties used in attribute create operations.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateAttributeDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateAttributeDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this CreateAttributeDetails.
        :type description: str

        :param external_data_type:
            The value to assign to the external_data_type property of this CreateAttributeDetails.
        :type external_data_type: str

        :param is_incremental_data:
            The value to assign to the is_incremental_data property of this CreateAttributeDetails.
        :type is_incremental_data: bool

        :param is_nullable:
            The value to assign to the is_nullable property of this CreateAttributeDetails.
        :type is_nullable: bool

        :param length:
            The value to assign to the length property of this CreateAttributeDetails.
        :type length: int

        :param position:
            The value to assign to the position property of this CreateAttributeDetails.
        :type position: int

        :param precision:
            The value to assign to the precision property of this CreateAttributeDetails.
        :type precision: int

        :param scale:
            The value to assign to the scale property of this CreateAttributeDetails.
        :type scale: int

        :param time_external:
            The value to assign to the time_external property of this CreateAttributeDetails.
        :type time_external: datetime

        :param min_collection_count:
            The value to assign to the min_collection_count property of this CreateAttributeDetails.
        :type min_collection_count: int

        :param max_collection_count:
            The value to assign to the max_collection_count property of this CreateAttributeDetails.
        :type max_collection_count: int

        :param external_datatype_entity_key:
            The value to assign to the external_datatype_entity_key property of this CreateAttributeDetails.
        :type external_datatype_entity_key: str

        :param external_parent_attribute_key:
            The value to assign to the external_parent_attribute_key property of this CreateAttributeDetails.
        :type external_parent_attribute_key: str

        :param properties:
            The value to assign to the properties property of this CreateAttributeDetails.
        :type properties: dict(str, dict(str, str))

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'external_data_type': 'str',
            'is_incremental_data': 'bool',
            'is_nullable': 'bool',
            'length': 'int',
            'position': 'int',
            'precision': 'int',
            'scale': 'int',
            'time_external': 'datetime',
            'min_collection_count': 'int',
            'max_collection_count': 'int',
            'external_datatype_entity_key': 'str',
            'external_parent_attribute_key': 'str',
            'properties': 'dict(str, dict(str, str))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'external_data_type': 'externalDataType',
            'is_incremental_data': 'isIncrementalData',
            'is_nullable': 'isNullable',
            'length': 'length',
            'position': 'position',
            'precision': 'precision',
            'scale': 'scale',
            'time_external': 'timeExternal',
            'min_collection_count': 'minCollectionCount',
            'max_collection_count': 'maxCollectionCount',
            'external_datatype_entity_key': 'externalDatatypeEntityKey',
            'external_parent_attribute_key': 'externalParentAttributeKey',
            'properties': 'properties'
        }

        self._display_name = None
        self._description = None
        self._external_data_type = None
        self._is_incremental_data = None
        self._is_nullable = None
        self._length = None
        self._position = None
        self._precision = None
        self._scale = None
        self._time_external = None
        self._min_collection_count = None
        self._max_collection_count = None
        self._external_datatype_entity_key = None
        self._external_parent_attribute_key = None
        self._properties = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateAttributeDetails.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this CreateAttributeDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateAttributeDetails.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this CreateAttributeDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this CreateAttributeDetails.
        Detailed description of the attribute.


        :return: The description of this CreateAttributeDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateAttributeDetails.
        Detailed description of the attribute.


        :param description: The description of this CreateAttributeDetails.
        :type: str
        """
        self._description = description

    @property
    def external_data_type(self):
        """
        **[Required]** Gets the external_data_type of this CreateAttributeDetails.
        Data type of the attribute as defined in the external system.


        :return: The external_data_type of this CreateAttributeDetails.
        :rtype: str
        """
        return self._external_data_type

    @external_data_type.setter
    def external_data_type(self, external_data_type):
        """
        Sets the external_data_type of this CreateAttributeDetails.
        Data type of the attribute as defined in the external system.


        :param external_data_type: The external_data_type of this CreateAttributeDetails.
        :type: str
        """
        self._external_data_type = external_data_type

    @property
    def is_incremental_data(self):
        """
        Gets the is_incremental_data of this CreateAttributeDetails.
        Property that identifies if this attribute can be used as a watermark to extract incremental data.


        :return: The is_incremental_data of this CreateAttributeDetails.
        :rtype: bool
        """
        return self._is_incremental_data

    @is_incremental_data.setter
    def is_incremental_data(self, is_incremental_data):
        """
        Sets the is_incremental_data of this CreateAttributeDetails.
        Property that identifies if this attribute can be used as a watermark to extract incremental data.


        :param is_incremental_data: The is_incremental_data of this CreateAttributeDetails.
        :type: bool
        """
        self._is_incremental_data = is_incremental_data

    @property
    def is_nullable(self):
        """
        Gets the is_nullable of this CreateAttributeDetails.
        Property that identifies if this attribute can be assigned null values.


        :return: The is_nullable of this CreateAttributeDetails.
        :rtype: bool
        """
        return self._is_nullable

    @is_nullable.setter
    def is_nullable(self, is_nullable):
        """
        Sets the is_nullable of this CreateAttributeDetails.
        Property that identifies if this attribute can be assigned null values.


        :param is_nullable: The is_nullable of this CreateAttributeDetails.
        :type: bool
        """
        self._is_nullable = is_nullable

    @property
    def length(self):
        """
        Gets the length of this CreateAttributeDetails.
        Max allowed length of the attribute value.


        :return: The length of this CreateAttributeDetails.
        :rtype: int
        """
        return self._length

    @length.setter
    def length(self, length):
        """
        Sets the length of this CreateAttributeDetails.
        Max allowed length of the attribute value.


        :param length: The length of this CreateAttributeDetails.
        :type: int
        """
        self._length = length

    @property
    def position(self):
        """
        Gets the position of this CreateAttributeDetails.
        Position of the attribute in the record definition.


        :return: The position of this CreateAttributeDetails.
        :rtype: int
        """
        return self._position

    @position.setter
    def position(self, position):
        """
        Sets the position of this CreateAttributeDetails.
        Position of the attribute in the record definition.


        :param position: The position of this CreateAttributeDetails.
        :type: int
        """
        self._position = position

    @property
    def precision(self):
        """
        Gets the precision of this CreateAttributeDetails.
        Precision of the attribute value usually applies to float data type.


        :return: The precision of this CreateAttributeDetails.
        :rtype: int
        """
        return self._precision

    @precision.setter
    def precision(self, precision):
        """
        Sets the precision of this CreateAttributeDetails.
        Precision of the attribute value usually applies to float data type.


        :param precision: The precision of this CreateAttributeDetails.
        :type: int
        """
        self._precision = precision

    @property
    def scale(self):
        """
        Gets the scale of this CreateAttributeDetails.
        Scale of the attribute value usually applies to float data type.


        :return: The scale of this CreateAttributeDetails.
        :rtype: int
        """
        return self._scale

    @scale.setter
    def scale(self, scale):
        """
        Sets the scale of this CreateAttributeDetails.
        Scale of the attribute value usually applies to float data type.


        :param scale: The scale of this CreateAttributeDetails.
        :type: int
        """
        self._scale = scale

    @property
    def time_external(self):
        """
        **[Required]** Gets the time_external of this CreateAttributeDetails.
        Last modified timestamp of this object in the external system.


        :return: The time_external of this CreateAttributeDetails.
        :rtype: datetime
        """
        return self._time_external

    @time_external.setter
    def time_external(self, time_external):
        """
        Sets the time_external of this CreateAttributeDetails.
        Last modified timestamp of this object in the external system.


        :param time_external: The time_external of this CreateAttributeDetails.
        :type: datetime
        """
        self._time_external = time_external

    @property
    def min_collection_count(self):
        """
        Gets the min_collection_count of this CreateAttributeDetails.
        The minimum count for the number of instances of a given type stored in this collection type attribute,applicable if this attribute is a complex type.


        :return: The min_collection_count of this CreateAttributeDetails.
        :rtype: int
        """
        return self._min_collection_count

    @min_collection_count.setter
    def min_collection_count(self, min_collection_count):
        """
        Sets the min_collection_count of this CreateAttributeDetails.
        The minimum count for the number of instances of a given type stored in this collection type attribute,applicable if this attribute is a complex type.


        :param min_collection_count: The min_collection_count of this CreateAttributeDetails.
        :type: int
        """
        self._min_collection_count = min_collection_count

    @property
    def max_collection_count(self):
        """
        Gets the max_collection_count of this CreateAttributeDetails.
        The maximum count for the number of instances of a given type stored in this collection type attribute,applicable if this attribute is a complex type.
        For type specifications in systems that specify only \"capacity\" without upper or lower bound , this property can also be used to just mean \"capacity\".
        Some examples are Varray size in Oracle , Occurs Clause in Cobol , capacity in XmlSchemaObjectCollection , maxOccurs in  Xml , maxItems in Json


        :return: The max_collection_count of this CreateAttributeDetails.
        :rtype: int
        """
        return self._max_collection_count

    @max_collection_count.setter
    def max_collection_count(self, max_collection_count):
        """
        Sets the max_collection_count of this CreateAttributeDetails.
        The maximum count for the number of instances of a given type stored in this collection type attribute,applicable if this attribute is a complex type.
        For type specifications in systems that specify only \"capacity\" without upper or lower bound , this property can also be used to just mean \"capacity\".
        Some examples are Varray size in Oracle , Occurs Clause in Cobol , capacity in XmlSchemaObjectCollection , maxOccurs in  Xml , maxItems in Json


        :param max_collection_count: The max_collection_count of this CreateAttributeDetails.
        :type: int
        """
        self._max_collection_count = max_collection_count

    @property
    def external_datatype_entity_key(self):
        """
        Gets the external_datatype_entity_key of this CreateAttributeDetails.
        External entity key that represents the datatype of this attribute , applicable if this attribute is a complex type.


        :return: The external_datatype_entity_key of this CreateAttributeDetails.
        :rtype: str
        """
        return self._external_datatype_entity_key

    @external_datatype_entity_key.setter
    def external_datatype_entity_key(self, external_datatype_entity_key):
        """
        Sets the external_datatype_entity_key of this CreateAttributeDetails.
        External entity key that represents the datatype of this attribute , applicable if this attribute is a complex type.


        :param external_datatype_entity_key: The external_datatype_entity_key of this CreateAttributeDetails.
        :type: str
        """
        self._external_datatype_entity_key = external_datatype_entity_key

    @property
    def external_parent_attribute_key(self):
        """
        Gets the external_parent_attribute_key of this CreateAttributeDetails.
        External attribute key that represents the parent attribute  of this attribute , applicable if the parent attribute is of complex type.


        :return: The external_parent_attribute_key of this CreateAttributeDetails.
        :rtype: str
        """
        return self._external_parent_attribute_key

    @external_parent_attribute_key.setter
    def external_parent_attribute_key(self, external_parent_attribute_key):
        """
        Sets the external_parent_attribute_key of this CreateAttributeDetails.
        External attribute key that represents the parent attribute  of this attribute , applicable if the parent attribute is of complex type.


        :param external_parent_attribute_key: The external_parent_attribute_key of this CreateAttributeDetails.
        :type: str
        """
        self._external_parent_attribute_key = external_parent_attribute_key

    @property
    def properties(self):
        """
        Gets the properties of this CreateAttributeDetails.
        A map of maps that contains the properties which are specific to the attribute type. Each attribute type
        definition defines it's set of required and optional properties. The map keys are category names and the
        values are maps of property name to property value. Every property is contained inside of a category. Most
        attributes have required properties within the \"default\" category. To determine the set of required and
        optional properties for an attribute type, a query can be done on '/types?type=attribute' that returns a
        collection of all attribute types. The appropriate attribute type, which will include definitions of all
        of it's properties, can be identified from this collection.
        Example: `{\"properties\": { \"default\": { \"key1\": \"value1\"}}}`


        :return: The properties of this CreateAttributeDetails.
        :rtype: dict(str, dict(str, str))
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this CreateAttributeDetails.
        A map of maps that contains the properties which are specific to the attribute type. Each attribute type
        definition defines it's set of required and optional properties. The map keys are category names and the
        values are maps of property name to property value. Every property is contained inside of a category. Most
        attributes have required properties within the \"default\" category. To determine the set of required and
        optional properties for an attribute type, a query can be done on '/types?type=attribute' that returns a
        collection of all attribute types. The appropriate attribute type, which will include definitions of all
        of it's properties, can be identified from this collection.
        Example: `{\"properties\": { \"default\": { \"key1\": \"value1\"}}}`


        :param properties: The properties of this CreateAttributeDetails.
        :type: dict(str, dict(str, str))
        """
        self._properties = properties

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AccessRule(object):
    """
    A content access rule. An access rule specifies an action to take if a set of criteria is matched by a request.
    """

    #: A constant which can be used with the action property of a AccessRule.
    #: This constant has a value of "ALLOW"
    ACTION_ALLOW = "ALLOW"

    #: A constant which can be used with the action property of a AccessRule.
    #: This constant has a value of "DETECT"
    ACTION_DETECT = "DETECT"

    #: A constant which can be used with the action property of a AccessRule.
    #: This constant has a value of "BLOCK"
    ACTION_BLOCK = "BLOCK"

    #: A constant which can be used with the action property of a AccessRule.
    #: This constant has a value of "BYPASS"
    ACTION_BYPASS = "BYPASS"

    #: A constant which can be used with the action property of a AccessRule.
    #: This constant has a value of "REDIRECT"
    ACTION_REDIRECT = "REDIRECT"

    #: A constant which can be used with the action property of a AccessRule.
    #: This constant has a value of "SHOW_CAPTCHA"
    ACTION_SHOW_CAPTCHA = "SHOW_CAPTCHA"

    #: A constant which can be used with the block_action property of a AccessRule.
    #: This constant has a value of "SET_RESPONSE_CODE"
    BLOCK_ACTION_SET_RESPONSE_CODE = "SET_RESPONSE_CODE"

    #: A constant which can be used with the block_action property of a AccessRule.
    #: This constant has a value of "SHOW_ERROR_PAGE"
    BLOCK_ACTION_SHOW_ERROR_PAGE = "SHOW_ERROR_PAGE"

    #: A constant which can be used with the bypass_challenges property of a AccessRule.
    #: This constant has a value of "JS_CHALLENGE"
    BYPASS_CHALLENGES_JS_CHALLENGE = "JS_CHALLENGE"

    #: A constant which can be used with the bypass_challenges property of a AccessRule.
    #: This constant has a value of "DEVICE_FINGERPRINT_CHALLENGE"
    BYPASS_CHALLENGES_DEVICE_FINGERPRINT_CHALLENGE = "DEVICE_FINGERPRINT_CHALLENGE"

    #: A constant which can be used with the bypass_challenges property of a AccessRule.
    #: This constant has a value of "HUMAN_INTERACTION_CHALLENGE"
    BYPASS_CHALLENGES_HUMAN_INTERACTION_CHALLENGE = "HUMAN_INTERACTION_CHALLENGE"

    #: A constant which can be used with the bypass_challenges property of a AccessRule.
    #: This constant has a value of "CAPTCHA"
    BYPASS_CHALLENGES_CAPTCHA = "CAPTCHA"

    #: A constant which can be used with the redirect_response_code property of a AccessRule.
    #: This constant has a value of "MOVED_PERMANENTLY"
    REDIRECT_RESPONSE_CODE_MOVED_PERMANENTLY = "MOVED_PERMANENTLY"

    #: A constant which can be used with the redirect_response_code property of a AccessRule.
    #: This constant has a value of "FOUND"
    REDIRECT_RESPONSE_CODE_FOUND = "FOUND"

    def __init__(self, **kwargs):
        """
        Initializes a new AccessRule object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this AccessRule.
        :type name: str

        :param criteria:
            The value to assign to the criteria property of this AccessRule.
        :type criteria: list[AccessRuleCriteria]

        :param action:
            The value to assign to the action property of this AccessRule.
            Allowed values for this property are: "ALLOW", "DETECT", "BLOCK", "BYPASS", "REDIRECT", "SHOW_CAPTCHA", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type action: str

        :param block_action:
            The value to assign to the block_action property of this AccessRule.
            Allowed values for this property are: "SET_RESPONSE_CODE", "SHOW_ERROR_PAGE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type block_action: str

        :param block_response_code:
            The value to assign to the block_response_code property of this AccessRule.
        :type block_response_code: int

        :param block_error_page_message:
            The value to assign to the block_error_page_message property of this AccessRule.
        :type block_error_page_message: str

        :param block_error_page_code:
            The value to assign to the block_error_page_code property of this AccessRule.
        :type block_error_page_code: str

        :param block_error_page_description:
            The value to assign to the block_error_page_description property of this AccessRule.
        :type block_error_page_description: str

        :param bypass_challenges:
            The value to assign to the bypass_challenges property of this AccessRule.
            Allowed values for items in this list are: "JS_CHALLENGE", "DEVICE_FINGERPRINT_CHALLENGE", "HUMAN_INTERACTION_CHALLENGE", "CAPTCHA", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type bypass_challenges: list[str]

        :param redirect_url:
            The value to assign to the redirect_url property of this AccessRule.
        :type redirect_url: str

        :param redirect_response_code:
            The value to assign to the redirect_response_code property of this AccessRule.
            Allowed values for this property are: "MOVED_PERMANENTLY", "FOUND", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type redirect_response_code: str

        :param captcha_title:
            The value to assign to the captcha_title property of this AccessRule.
        :type captcha_title: str

        :param captcha_header:
            The value to assign to the captcha_header property of this AccessRule.
        :type captcha_header: str

        :param captcha_footer:
            The value to assign to the captcha_footer property of this AccessRule.
        :type captcha_footer: str

        :param captcha_submit_label:
            The value to assign to the captcha_submit_label property of this AccessRule.
        :type captcha_submit_label: str

        :param response_header_manipulation:
            The value to assign to the response_header_manipulation property of this AccessRule.
        :type response_header_manipulation: list[HeaderManipulationAction]

        """
        self.swagger_types = {
            'name': 'str',
            'criteria': 'list[AccessRuleCriteria]',
            'action': 'str',
            'block_action': 'str',
            'block_response_code': 'int',
            'block_error_page_message': 'str',
            'block_error_page_code': 'str',
            'block_error_page_description': 'str',
            'bypass_challenges': 'list[str]',
            'redirect_url': 'str',
            'redirect_response_code': 'str',
            'captcha_title': 'str',
            'captcha_header': 'str',
            'captcha_footer': 'str',
            'captcha_submit_label': 'str',
            'response_header_manipulation': 'list[HeaderManipulationAction]'
        }

        self.attribute_map = {
            'name': 'name',
            'criteria': 'criteria',
            'action': 'action',
            'block_action': 'blockAction',
            'block_response_code': 'blockResponseCode',
            'block_error_page_message': 'blockErrorPageMessage',
            'block_error_page_code': 'blockErrorPageCode',
            'block_error_page_description': 'blockErrorPageDescription',
            'bypass_challenges': 'bypassChallenges',
            'redirect_url': 'redirectUrl',
            'redirect_response_code': 'redirectResponseCode',
            'captcha_title': 'captchaTitle',
            'captcha_header': 'captchaHeader',
            'captcha_footer': 'captchaFooter',
            'captcha_submit_label': 'captchaSubmitLabel',
            'response_header_manipulation': 'responseHeaderManipulation'
        }

        self._name = None
        self._criteria = None
        self._action = None
        self._block_action = None
        self._block_response_code = None
        self._block_error_page_message = None
        self._block_error_page_code = None
        self._block_error_page_description = None
        self._bypass_challenges = None
        self._redirect_url = None
        self._redirect_response_code = None
        self._captcha_title = None
        self._captcha_header = None
        self._captcha_footer = None
        self._captcha_submit_label = None
        self._response_header_manipulation = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this AccessRule.
        The unique name of the access rule.


        :return: The name of this AccessRule.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AccessRule.
        The unique name of the access rule.


        :param name: The name of this AccessRule.
        :type: str
        """
        self._name = name

    @property
    def criteria(self):
        """
        **[Required]** Gets the criteria of this AccessRule.
        The list of access rule criteria. The rule would be applied only for the requests that matched all the listed conditions.


        :return: The criteria of this AccessRule.
        :rtype: list[AccessRuleCriteria]
        """
        return self._criteria

    @criteria.setter
    def criteria(self, criteria):
        """
        Sets the criteria of this AccessRule.
        The list of access rule criteria. The rule would be applied only for the requests that matched all the listed conditions.


        :param criteria: The criteria of this AccessRule.
        :type: list[AccessRuleCriteria]
        """
        self._criteria = criteria

    @property
    def action(self):
        """
        **[Required]** Gets the action of this AccessRule.
        The action to take when the access criteria are met for a rule. If unspecified, defaults to `ALLOW`.

        - **ALLOW:** Takes no action, just logs the request.

        - **DETECT:** Takes no action, but creates an alert for the request.

        - **BLOCK:** Blocks the request by returning specified response code or showing error page.

        - **BYPASS:** Bypasses some or all challenges.

        - **REDIRECT:** Redirects the request to the specified URL. These fields are required when `REDIRECT` is selected: `redirectUrl`, `redirectResponseCode`.

        - **SHOW_CAPTCHA:** Show a CAPTCHA Challenge page instead of the requested page.

        Regardless of action, no further rules are processed once a rule is matched.

        Allowed values for this property are: "ALLOW", "DETECT", "BLOCK", "BYPASS", "REDIRECT", "SHOW_CAPTCHA", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The action of this AccessRule.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this AccessRule.
        The action to take when the access criteria are met for a rule. If unspecified, defaults to `ALLOW`.

        - **ALLOW:** Takes no action, just logs the request.

        - **DETECT:** Takes no action, but creates an alert for the request.

        - **BLOCK:** Blocks the request by returning specified response code or showing error page.

        - **BYPASS:** Bypasses some or all challenges.

        - **REDIRECT:** Redirects the request to the specified URL. These fields are required when `REDIRECT` is selected: `redirectUrl`, `redirectResponseCode`.

        - **SHOW_CAPTCHA:** Show a CAPTCHA Challenge page instead of the requested page.

        Regardless of action, no further rules are processed once a rule is matched.


        :param action: The action of this AccessRule.
        :type: str
        """
        allowed_values = ["ALLOW", "DETECT", "BLOCK", "BYPASS", "REDIRECT", "SHOW_CAPTCHA"]
        if not value_allowed_none_or_none_sentinel(action, allowed_values):
            action = 'UNKNOWN_ENUM_VALUE'
        self._action = action

    @property
    def block_action(self):
        """
        Gets the block_action of this AccessRule.
        The method used to block requests if `action` is set to `BLOCK` and the access criteria are met. If unspecified, defaults to `SET_RESPONSE_CODE`.

        Allowed values for this property are: "SET_RESPONSE_CODE", "SHOW_ERROR_PAGE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The block_action of this AccessRule.
        :rtype: str
        """
        return self._block_action

    @block_action.setter
    def block_action(self, block_action):
        """
        Sets the block_action of this AccessRule.
        The method used to block requests if `action` is set to `BLOCK` and the access criteria are met. If unspecified, defaults to `SET_RESPONSE_CODE`.


        :param block_action: The block_action of this AccessRule.
        :type: str
        """
        allowed_values = ["SET_RESPONSE_CODE", "SHOW_ERROR_PAGE"]
        if not value_allowed_none_or_none_sentinel(block_action, allowed_values):
            block_action = 'UNKNOWN_ENUM_VALUE'
        self._block_action = block_action

    @property
    def block_response_code(self):
        """
        Gets the block_response_code of this AccessRule.
        The response status code to return when `action` is set to `BLOCK`, `blockAction` is set to `SET_RESPONSE_CODE`, and the access criteria are met. If unspecified, defaults to `403`. The list of available response codes: `200`, `201`, `202`, `204`, `206`, `300`, `301`, `302`, `303`, `304`, `307`, `400`, `401`, `403`, `404`, `405`, `408`, `409`, `411`, `412`, `413`, `414`, `415`, `416`, `422`, `444`, `499`, `500`, `501`, `502`, `503`, `504`, `507`.


        :return: The block_response_code of this AccessRule.
        :rtype: int
        """
        return self._block_response_code

    @block_response_code.setter
    def block_response_code(self, block_response_code):
        """
        Sets the block_response_code of this AccessRule.
        The response status code to return when `action` is set to `BLOCK`, `blockAction` is set to `SET_RESPONSE_CODE`, and the access criteria are met. If unspecified, defaults to `403`. The list of available response codes: `200`, `201`, `202`, `204`, `206`, `300`, `301`, `302`, `303`, `304`, `307`, `400`, `401`, `403`, `404`, `405`, `408`, `409`, `411`, `412`, `413`, `414`, `415`, `416`, `422`, `444`, `499`, `500`, `501`, `502`, `503`, `504`, `507`.


        :param block_response_code: The block_response_code of this AccessRule.
        :type: int
        """
        self._block_response_code = block_response_code

    @property
    def block_error_page_message(self):
        """
        Gets the block_error_page_message of this AccessRule.
        The message to show on the error page when `action` is set to `BLOCK`, `blockAction` is set to `SHOW_ERROR_PAGE`, and the access criteria are met. If unspecified, defaults to 'Access to the website is blocked.'


        :return: The block_error_page_message of this AccessRule.
        :rtype: str
        """
        return self._block_error_page_message

    @block_error_page_message.setter
    def block_error_page_message(self, block_error_page_message):
        """
        Sets the block_error_page_message of this AccessRule.
        The message to show on the error page when `action` is set to `BLOCK`, `blockAction` is set to `SHOW_ERROR_PAGE`, and the access criteria are met. If unspecified, defaults to 'Access to the website is blocked.'


        :param block_error_page_message: The block_error_page_message of this AccessRule.
        :type: str
        """
        self._block_error_page_message = block_error_page_message

    @property
    def block_error_page_code(self):
        """
        Gets the block_error_page_code of this AccessRule.
        The error code to show on the error page when `action` is set to `BLOCK`, `blockAction` is set to `SHOW_ERROR_PAGE`, and the access criteria are met. If unspecified, defaults to 'Access rules'.


        :return: The block_error_page_code of this AccessRule.
        :rtype: str
        """
        return self._block_error_page_code

    @block_error_page_code.setter
    def block_error_page_code(self, block_error_page_code):
        """
        Sets the block_error_page_code of this AccessRule.
        The error code to show on the error page when `action` is set to `BLOCK`, `blockAction` is set to `SHOW_ERROR_PAGE`, and the access criteria are met. If unspecified, defaults to 'Access rules'.


        :param block_error_page_code: The block_error_page_code of this AccessRule.
        :type: str
        """
        self._block_error_page_code = block_error_page_code

    @property
    def block_error_page_description(self):
        """
        Gets the block_error_page_description of this AccessRule.
        The description text to show on the error page when `action` is set to `BLOCK`, `blockAction` is set to `SHOW_ERROR_PAGE`, and the access criteria are met. If unspecified, defaults to 'Access blocked by website owner. Please contact support.'


        :return: The block_error_page_description of this AccessRule.
        :rtype: str
        """
        return self._block_error_page_description

    @block_error_page_description.setter
    def block_error_page_description(self, block_error_page_description):
        """
        Sets the block_error_page_description of this AccessRule.
        The description text to show on the error page when `action` is set to `BLOCK`, `blockAction` is set to `SHOW_ERROR_PAGE`, and the access criteria are met. If unspecified, defaults to 'Access blocked by website owner. Please contact support.'


        :param block_error_page_description: The block_error_page_description of this AccessRule.
        :type: str
        """
        self._block_error_page_description = block_error_page_description

    @property
    def bypass_challenges(self):
        """
        Gets the bypass_challenges of this AccessRule.
        The list of challenges to bypass when `action` is set to `BYPASS`. If unspecified or empty, all challenges are bypassed.

        - **JS_CHALLENGE:** Bypasses JavaScript Challenge.

        - **DEVICE_FINGERPRINT_CHALLENGE:** Bypasses Device Fingerprint Challenge.

        - **HUMAN_INTERACTION_CHALLENGE:** Bypasses Human Interaction Challenge.

        - **CAPTCHA:** Bypasses CAPTCHA Challenge.

        Allowed values for items in this list are: "JS_CHALLENGE", "DEVICE_FINGERPRINT_CHALLENGE", "HUMAN_INTERACTION_CHALLENGE", "CAPTCHA", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The bypass_challenges of this AccessRule.
        :rtype: list[str]
        """
        return self._bypass_challenges

    @bypass_challenges.setter
    def bypass_challenges(self, bypass_challenges):
        """
        Sets the bypass_challenges of this AccessRule.
        The list of challenges to bypass when `action` is set to `BYPASS`. If unspecified or empty, all challenges are bypassed.

        - **JS_CHALLENGE:** Bypasses JavaScript Challenge.

        - **DEVICE_FINGERPRINT_CHALLENGE:** Bypasses Device Fingerprint Challenge.

        - **HUMAN_INTERACTION_CHALLENGE:** Bypasses Human Interaction Challenge.

        - **CAPTCHA:** Bypasses CAPTCHA Challenge.


        :param bypass_challenges: The bypass_challenges of this AccessRule.
        :type: list[str]
        """
        allowed_values = ["JS_CHALLENGE", "DEVICE_FINGERPRINT_CHALLENGE", "HUMAN_INTERACTION_CHALLENGE", "CAPTCHA"]
        if bypass_challenges:
            bypass_challenges[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in bypass_challenges]
        self._bypass_challenges = bypass_challenges

    @property
    def redirect_url(self):
        """
        Gets the redirect_url of this AccessRule.
        The target to which the request should be redirected, represented as a URI reference. Required when `action` is `REDIRECT`.


        :return: The redirect_url of this AccessRule.
        :rtype: str
        """
        return self._redirect_url

    @redirect_url.setter
    def redirect_url(self, redirect_url):
        """
        Sets the redirect_url of this AccessRule.
        The target to which the request should be redirected, represented as a URI reference. Required when `action` is `REDIRECT`.


        :param redirect_url: The redirect_url of this AccessRule.
        :type: str
        """
        self._redirect_url = redirect_url

    @property
    def redirect_response_code(self):
        """
        Gets the redirect_response_code of this AccessRule.
        The response status code to return when `action` is set to `REDIRECT`.

        - **MOVED_PERMANENTLY:** Used for designating the permanent movement of a page (numerical code - 301).

        - **FOUND:** Used for designating the temporary movement of a page (numerical code - 302).

        Allowed values for this property are: "MOVED_PERMANENTLY", "FOUND", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The redirect_response_code of this AccessRule.
        :rtype: str
        """
        return self._redirect_response_code

    @redirect_response_code.setter
    def redirect_response_code(self, redirect_response_code):
        """
        Sets the redirect_response_code of this AccessRule.
        The response status code to return when `action` is set to `REDIRECT`.

        - **MOVED_PERMANENTLY:** Used for designating the permanent movement of a page (numerical code - 301).

        - **FOUND:** Used for designating the temporary movement of a page (numerical code - 302).


        :param redirect_response_code: The redirect_response_code of this AccessRule.
        :type: str
        """
        allowed_values = ["MOVED_PERMANENTLY", "FOUND"]
        if not value_allowed_none_or_none_sentinel(redirect_response_code, allowed_values):
            redirect_response_code = 'UNKNOWN_ENUM_VALUE'
        self._redirect_response_code = redirect_response_code

    @property
    def captcha_title(self):
        """
        Gets the captcha_title of this AccessRule.
        The title used when showing a CAPTCHA challenge when `action` is set to `SHOW_CAPTCHA` and the request is challenged.


        :return: The captcha_title of this AccessRule.
        :rtype: str
        """
        return self._captcha_title

    @captcha_title.setter
    def captcha_title(self, captcha_title):
        """
        Sets the captcha_title of this AccessRule.
        The title used when showing a CAPTCHA challenge when `action` is set to `SHOW_CAPTCHA` and the request is challenged.


        :param captcha_title: The captcha_title of this AccessRule.
        :type: str
        """
        self._captcha_title = captcha_title

    @property
    def captcha_header(self):
        """
        Gets the captcha_header of this AccessRule.
        The text to show in the header when showing a CAPTCHA challenge when `action` is set to `SHOW_CAPTCHA` and the request is challenged.


        :return: The captcha_header of this AccessRule.
        :rtype: str
        """
        return self._captcha_header

    @captcha_header.setter
    def captcha_header(self, captcha_header):
        """
        Sets the captcha_header of this AccessRule.
        The text to show in the header when showing a CAPTCHA challenge when `action` is set to `SHOW_CAPTCHA` and the request is challenged.


        :param captcha_header: The captcha_header of this AccessRule.
        :type: str
        """
        self._captcha_header = captcha_header

    @property
    def captcha_footer(self):
        """
        Gets the captcha_footer of this AccessRule.
        The text to show in the footer when showing a CAPTCHA challenge when `action` is set to `SHOW_CAPTCHA` and the request is challenged.


        :return: The captcha_footer of this AccessRule.
        :rtype: str
        """
        return self._captcha_footer

    @captcha_footer.setter
    def captcha_footer(self, captcha_footer):
        """
        Sets the captcha_footer of this AccessRule.
        The text to show in the footer when showing a CAPTCHA challenge when `action` is set to `SHOW_CAPTCHA` and the request is challenged.


        :param captcha_footer: The captcha_footer of this AccessRule.
        :type: str
        """
        self._captcha_footer = captcha_footer

    @property
    def captcha_submit_label(self):
        """
        Gets the captcha_submit_label of this AccessRule.
        The text to show on the label of the CAPTCHA challenge submit button when `action` is set to `SHOW_CAPTCHA` and the request is challenged.


        :return: The captcha_submit_label of this AccessRule.
        :rtype: str
        """
        return self._captcha_submit_label

    @captcha_submit_label.setter
    def captcha_submit_label(self, captcha_submit_label):
        """
        Sets the captcha_submit_label of this AccessRule.
        The text to show on the label of the CAPTCHA challenge submit button when `action` is set to `SHOW_CAPTCHA` and the request is challenged.


        :param captcha_submit_label: The captcha_submit_label of this AccessRule.
        :type: str
        """
        self._captcha_submit_label = captcha_submit_label

    @property
    def response_header_manipulation(self):
        """
        Gets the response_header_manipulation of this AccessRule.
        An object that represents an action to apply to an HTTP response headers if all rule criteria will be matched regardless of `action` value.


        :return: The response_header_manipulation of this AccessRule.
        :rtype: list[HeaderManipulationAction]
        """
        return self._response_header_manipulation

    @response_header_manipulation.setter
    def response_header_manipulation(self, response_header_manipulation):
        """
        Sets the response_header_manipulation of this AccessRule.
        An object that represents an action to apply to an HTTP response headers if all rule criteria will be matched regardless of `action` value.


        :param response_header_manipulation: The response_header_manipulation of this AccessRule.
        :type: list[HeaderManipulationAction]
        """
        self._response_header_manipulation = response_header_manipulation

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateAutonomousContainerDatabaseDetails(object):
    """
    Describes the required parameters for the creation of an Autonomous Container Database.
    """

    #: A constant which can be used with the service_level_agreement_type property of a CreateAutonomousContainerDatabaseDetails.
    #: This constant has a value of "STANDARD"
    SERVICE_LEVEL_AGREEMENT_TYPE_STANDARD = "STANDARD"

    #: A constant which can be used with the patch_model property of a CreateAutonomousContainerDatabaseDetails.
    #: This constant has a value of "RELEASE_UPDATES"
    PATCH_MODEL_RELEASE_UPDATES = "RELEASE_UPDATES"

    #: A constant which can be used with the patch_model property of a CreateAutonomousContainerDatabaseDetails.
    #: This constant has a value of "RELEASE_UPDATE_REVISIONS"
    PATCH_MODEL_RELEASE_UPDATE_REVISIONS = "RELEASE_UPDATE_REVISIONS"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateAutonomousContainerDatabaseDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateAutonomousContainerDatabaseDetails.
        :type display_name: str

        :param db_unique_name:
            The value to assign to the db_unique_name property of this CreateAutonomousContainerDatabaseDetails.
        :type db_unique_name: str

        :param service_level_agreement_type:
            The value to assign to the service_level_agreement_type property of this CreateAutonomousContainerDatabaseDetails.
            Allowed values for this property are: "STANDARD"
        :type service_level_agreement_type: str

        :param autonomous_exadata_infrastructure_id:
            The value to assign to the autonomous_exadata_infrastructure_id property of this CreateAutonomousContainerDatabaseDetails.
        :type autonomous_exadata_infrastructure_id: str

        :param autonomous_vm_cluster_id:
            The value to assign to the autonomous_vm_cluster_id property of this CreateAutonomousContainerDatabaseDetails.
        :type autonomous_vm_cluster_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateAutonomousContainerDatabaseDetails.
        :type compartment_id: str

        :param patch_model:
            The value to assign to the patch_model property of this CreateAutonomousContainerDatabaseDetails.
            Allowed values for this property are: "RELEASE_UPDATES", "RELEASE_UPDATE_REVISIONS"
        :type patch_model: str

        :param maintenance_window_details:
            The value to assign to the maintenance_window_details property of this CreateAutonomousContainerDatabaseDetails.
        :type maintenance_window_details: MaintenanceWindow

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateAutonomousContainerDatabaseDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateAutonomousContainerDatabaseDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param backup_config:
            The value to assign to the backup_config property of this CreateAutonomousContainerDatabaseDetails.
        :type backup_config: AutonomousContainerDatabaseBackupConfig

        """
        self.swagger_types = {
            'display_name': 'str',
            'db_unique_name': 'str',
            'service_level_agreement_type': 'str',
            'autonomous_exadata_infrastructure_id': 'str',
            'autonomous_vm_cluster_id': 'str',
            'compartment_id': 'str',
            'patch_model': 'str',
            'maintenance_window_details': 'MaintenanceWindow',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'backup_config': 'AutonomousContainerDatabaseBackupConfig'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'db_unique_name': 'dbUniqueName',
            'service_level_agreement_type': 'serviceLevelAgreementType',
            'autonomous_exadata_infrastructure_id': 'autonomousExadataInfrastructureId',
            'autonomous_vm_cluster_id': 'autonomousVmClusterId',
            'compartment_id': 'compartmentId',
            'patch_model': 'patchModel',
            'maintenance_window_details': 'maintenanceWindowDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'backup_config': 'backupConfig'
        }

        self._display_name = None
        self._db_unique_name = None
        self._service_level_agreement_type = None
        self._autonomous_exadata_infrastructure_id = None
        self._autonomous_vm_cluster_id = None
        self._compartment_id = None
        self._patch_model = None
        self._maintenance_window_details = None
        self._freeform_tags = None
        self._defined_tags = None
        self._backup_config = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateAutonomousContainerDatabaseDetails.
        The display name for the Autonomous Container Database.


        :return: The display_name of this CreateAutonomousContainerDatabaseDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateAutonomousContainerDatabaseDetails.
        The display name for the Autonomous Container Database.


        :param display_name: The display_name of this CreateAutonomousContainerDatabaseDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def db_unique_name(self):
        """
        Gets the db_unique_name of this CreateAutonomousContainerDatabaseDetails.
        The `DB_UNIQUE_NAME` of the Oracle Database being backed up.


        :return: The db_unique_name of this CreateAutonomousContainerDatabaseDetails.
        :rtype: str
        """
        return self._db_unique_name

    @db_unique_name.setter
    def db_unique_name(self, db_unique_name):
        """
        Sets the db_unique_name of this CreateAutonomousContainerDatabaseDetails.
        The `DB_UNIQUE_NAME` of the Oracle Database being backed up.


        :param db_unique_name: The db_unique_name of this CreateAutonomousContainerDatabaseDetails.
        :type: str
        """
        self._db_unique_name = db_unique_name

    @property
    def service_level_agreement_type(self):
        """
        Gets the service_level_agreement_type of this CreateAutonomousContainerDatabaseDetails.
        The service level agreement type of the Autonomous Container Database. The default is STANDARD. For an autonomous dataguard Autonomous Container Database, the specified Autonomous Exadata Infrastructure must be associated with a remote Autonomous Exadata Infrastructure.

        Allowed values for this property are: "STANDARD"


        :return: The service_level_agreement_type of this CreateAutonomousContainerDatabaseDetails.
        :rtype: str
        """
        return self._service_level_agreement_type

    @service_level_agreement_type.setter
    def service_level_agreement_type(self, service_level_agreement_type):
        """
        Sets the service_level_agreement_type of this CreateAutonomousContainerDatabaseDetails.
        The service level agreement type of the Autonomous Container Database. The default is STANDARD. For an autonomous dataguard Autonomous Container Database, the specified Autonomous Exadata Infrastructure must be associated with a remote Autonomous Exadata Infrastructure.


        :param service_level_agreement_type: The service_level_agreement_type of this CreateAutonomousContainerDatabaseDetails.
        :type: str
        """
        allowed_values = ["STANDARD"]
        if not value_allowed_none_or_none_sentinel(service_level_agreement_type, allowed_values):
            raise ValueError(
                "Invalid value for `service_level_agreement_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._service_level_agreement_type = service_level_agreement_type

    @property
    def autonomous_exadata_infrastructure_id(self):
        """
        Gets the autonomous_exadata_infrastructure_id of this CreateAutonomousContainerDatabaseDetails.
        The OCID of the Autonomous Exadata Infrastructure.


        :return: The autonomous_exadata_infrastructure_id of this CreateAutonomousContainerDatabaseDetails.
        :rtype: str
        """
        return self._autonomous_exadata_infrastructure_id

    @autonomous_exadata_infrastructure_id.setter
    def autonomous_exadata_infrastructure_id(self, autonomous_exadata_infrastructure_id):
        """
        Sets the autonomous_exadata_infrastructure_id of this CreateAutonomousContainerDatabaseDetails.
        The OCID of the Autonomous Exadata Infrastructure.


        :param autonomous_exadata_infrastructure_id: The autonomous_exadata_infrastructure_id of this CreateAutonomousContainerDatabaseDetails.
        :type: str
        """
        self._autonomous_exadata_infrastructure_id = autonomous_exadata_infrastructure_id

    @property
    def autonomous_vm_cluster_id(self):
        """
        Gets the autonomous_vm_cluster_id of this CreateAutonomousContainerDatabaseDetails.
        The OCID of the Autonomous VM Cluster.


        :return: The autonomous_vm_cluster_id of this CreateAutonomousContainerDatabaseDetails.
        :rtype: str
        """
        return self._autonomous_vm_cluster_id

    @autonomous_vm_cluster_id.setter
    def autonomous_vm_cluster_id(self, autonomous_vm_cluster_id):
        """
        Sets the autonomous_vm_cluster_id of this CreateAutonomousContainerDatabaseDetails.
        The OCID of the Autonomous VM Cluster.


        :param autonomous_vm_cluster_id: The autonomous_vm_cluster_id of this CreateAutonomousContainerDatabaseDetails.
        :type: str
        """
        self._autonomous_vm_cluster_id = autonomous_vm_cluster_id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this CreateAutonomousContainerDatabaseDetails.
        The `OCID`__ of the compartment containing the Autonomous Container Database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateAutonomousContainerDatabaseDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateAutonomousContainerDatabaseDetails.
        The `OCID`__ of the compartment containing the Autonomous Container Database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateAutonomousContainerDatabaseDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def patch_model(self):
        """
        **[Required]** Gets the patch_model of this CreateAutonomousContainerDatabaseDetails.
        Database Patch model preference.

        Allowed values for this property are: "RELEASE_UPDATES", "RELEASE_UPDATE_REVISIONS"


        :return: The patch_model of this CreateAutonomousContainerDatabaseDetails.
        :rtype: str
        """
        return self._patch_model

    @patch_model.setter
    def patch_model(self, patch_model):
        """
        Sets the patch_model of this CreateAutonomousContainerDatabaseDetails.
        Database Patch model preference.


        :param patch_model: The patch_model of this CreateAutonomousContainerDatabaseDetails.
        :type: str
        """
        allowed_values = ["RELEASE_UPDATES", "RELEASE_UPDATE_REVISIONS"]
        if not value_allowed_none_or_none_sentinel(patch_model, allowed_values):
            raise ValueError(
                "Invalid value for `patch_model`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._patch_model = patch_model

    @property
    def maintenance_window_details(self):
        """
        Gets the maintenance_window_details of this CreateAutonomousContainerDatabaseDetails.

        :return: The maintenance_window_details of this CreateAutonomousContainerDatabaseDetails.
        :rtype: MaintenanceWindow
        """
        return self._maintenance_window_details

    @maintenance_window_details.setter
    def maintenance_window_details(self, maintenance_window_details):
        """
        Sets the maintenance_window_details of this CreateAutonomousContainerDatabaseDetails.

        :param maintenance_window_details: The maintenance_window_details of this CreateAutonomousContainerDatabaseDetails.
        :type: MaintenanceWindow
        """
        self._maintenance_window_details = maintenance_window_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateAutonomousContainerDatabaseDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateAutonomousContainerDatabaseDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateAutonomousContainerDatabaseDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateAutonomousContainerDatabaseDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateAutonomousContainerDatabaseDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateAutonomousContainerDatabaseDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateAutonomousContainerDatabaseDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateAutonomousContainerDatabaseDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def backup_config(self):
        """
        Gets the backup_config of this CreateAutonomousContainerDatabaseDetails.

        :return: The backup_config of this CreateAutonomousContainerDatabaseDetails.
        :rtype: AutonomousContainerDatabaseBackupConfig
        """
        return self._backup_config

    @backup_config.setter
    def backup_config(self, backup_config):
        """
        Sets the backup_config of this CreateAutonomousContainerDatabaseDetails.

        :param backup_config: The backup_config of this CreateAutonomousContainerDatabaseDetails.
        :type: AutonomousContainerDatabaseBackupConfig
        """
        self._backup_config = backup_config

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LBCookieSessionPersistenceConfigurationDetails(object):
    """
    The configuration details for implementing load balancer cookie session persistence (LB cookie stickiness).

    Session persistence enables the Load Balancing service to direct all requests that originate from a single logical
    client to a single backend web server. For more information, see
    `Session Persistence`__.

    When you configure LB cookie stickiness, the load balancer inserts a cookie into the response. The parameters configured
    in the cookie enable session stickiness. This method is useful when you have applications and Web backend services
    that cannot generate their own cookies.

    Path route rules take precedence to determine the target backend server. The load balancer verifies that session stickiness
    is enabled for the backend server and that the cookie configuration (domain, path, and cookie hash) is valid for the
    target. The system ignores invalid cookies.

    To disable LB cookie stickiness on a running load balancer, use the
    :func:`update_backend_set` operation and specify `null` for the
    `LBCookieSessionPersistenceConfigurationDetails` object.

    Example: `LBCookieSessionPersistenceConfigurationDetails: null`

    **Note:** `SessionPersistenceConfigurationDetails` (application cookie stickiness) and `LBCookieSessionPersistenceConfigurationDetails`
    (LB cookie stickiness) are mutually exclusive. An error results if you try to enable both types of session persistence.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.

    __ https://docs.cloud.oracle.com/Content/Balance/Reference/sessionpersistence.htm
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LBCookieSessionPersistenceConfigurationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param cookie_name:
            The value to assign to the cookie_name property of this LBCookieSessionPersistenceConfigurationDetails.
        :type cookie_name: str

        :param disable_fallback:
            The value to assign to the disable_fallback property of this LBCookieSessionPersistenceConfigurationDetails.
        :type disable_fallback: bool

        :param domain:
            The value to assign to the domain property of this LBCookieSessionPersistenceConfigurationDetails.
        :type domain: str

        :param path:
            The value to assign to the path property of this LBCookieSessionPersistenceConfigurationDetails.
        :type path: str

        :param max_age_in_seconds:
            The value to assign to the max_age_in_seconds property of this LBCookieSessionPersistenceConfigurationDetails.
        :type max_age_in_seconds: int

        :param is_secure:
            The value to assign to the is_secure property of this LBCookieSessionPersistenceConfigurationDetails.
        :type is_secure: bool

        :param is_http_only:
            The value to assign to the is_http_only property of this LBCookieSessionPersistenceConfigurationDetails.
        :type is_http_only: bool

        """
        self.swagger_types = {
            'cookie_name': 'str',
            'disable_fallback': 'bool',
            'domain': 'str',
            'path': 'str',
            'max_age_in_seconds': 'int',
            'is_secure': 'bool',
            'is_http_only': 'bool'
        }

        self.attribute_map = {
            'cookie_name': 'cookieName',
            'disable_fallback': 'disableFallback',
            'domain': 'domain',
            'path': 'path',
            'max_age_in_seconds': 'maxAgeInSeconds',
            'is_secure': 'isSecure',
            'is_http_only': 'isHttpOnly'
        }

        self._cookie_name = None
        self._disable_fallback = None
        self._domain = None
        self._path = None
        self._max_age_in_seconds = None
        self._is_secure = None
        self._is_http_only = None

    @property
    def cookie_name(self):
        """
        Gets the cookie_name of this LBCookieSessionPersistenceConfigurationDetails.
        The name of the cookie inserted by the load balancer. If this field is not configured, the cookie name defaults
        to \"X-Oracle-BMC-LBS-Route\".

        Example: `example_cookie`

        **Notes:**

        *  Ensure that the cookie name used at the backend application servers is different from the cookie name used
           at the load balancer. To minimize the chance of name collision, Oracle recommends that you use a prefix
           such as \"X-Oracle-OCI-\" for this field.

        *  If a backend server and the load balancer both insert cookies with the same name, the client or browser
           behavior can vary depending on the domain and path values associated with the cookie. If the name, domain,
           and path values of the `Set-cookie` generated by a backend server and the `Set-cookie` generated by the
           load balancer are all the same, the client or browser treats them as one cookie and returns only one of
           the cookie values in subsequent requests. If both `Set-cookie` names are the same, but the domain and path
           names are different, the client or browser treats them as two different cookies.


        :return: The cookie_name of this LBCookieSessionPersistenceConfigurationDetails.
        :rtype: str
        """
        return self._cookie_name

    @cookie_name.setter
    def cookie_name(self, cookie_name):
        """
        Sets the cookie_name of this LBCookieSessionPersistenceConfigurationDetails.
        The name of the cookie inserted by the load balancer. If this field is not configured, the cookie name defaults
        to \"X-Oracle-BMC-LBS-Route\".

        Example: `example_cookie`

        **Notes:**

        *  Ensure that the cookie name used at the backend application servers is different from the cookie name used
           at the load balancer. To minimize the chance of name collision, Oracle recommends that you use a prefix
           such as \"X-Oracle-OCI-\" for this field.

        *  If a backend server and the load balancer both insert cookies with the same name, the client or browser
           behavior can vary depending on the domain and path values associated with the cookie. If the name, domain,
           and path values of the `Set-cookie` generated by a backend server and the `Set-cookie` generated by the
           load balancer are all the same, the client or browser treats them as one cookie and returns only one of
           the cookie values in subsequent requests. If both `Set-cookie` names are the same, but the domain and path
           names are different, the client or browser treats them as two different cookies.


        :param cookie_name: The cookie_name of this LBCookieSessionPersistenceConfigurationDetails.
        :type: str
        """
        self._cookie_name = cookie_name

    @property
    def disable_fallback(self):
        """
        Gets the disable_fallback of this LBCookieSessionPersistenceConfigurationDetails.
        Whether the load balancer is prevented from directing traffic from a persistent session client to
        a different backend server if the original server is unavailable. Defaults to false.

        Example: `false`


        :return: The disable_fallback of this LBCookieSessionPersistenceConfigurationDetails.
        :rtype: bool
        """
        return self._disable_fallback

    @disable_fallback.setter
    def disable_fallback(self, disable_fallback):
        """
        Sets the disable_fallback of this LBCookieSessionPersistenceConfigurationDetails.
        Whether the load balancer is prevented from directing traffic from a persistent session client to
        a different backend server if the original server is unavailable. Defaults to false.

        Example: `false`


        :param disable_fallback: The disable_fallback of this LBCookieSessionPersistenceConfigurationDetails.
        :type: bool
        """
        self._disable_fallback = disable_fallback

    @property
    def domain(self):
        """
        Gets the domain of this LBCookieSessionPersistenceConfigurationDetails.
        The domain in which the cookie is valid. The `Set-cookie` header inserted by the load balancer contains a
        domain attribute with the specified value.

        This attribute has no default value. If you do not specify a value, the load balancer does not insert the domain
        attribute into the `Set-cookie` header.

        **Notes:**

        *  `RFC 6265 - HTTP State Management Mechanism`__ describes client and
           browser behavior when the domain attribute is present or not present in the `Set-cookie` header.

           If the value of the `Domain` attribute is `example.com` in the `Set-cookie` header, the client includes
           the same cookie in the `Cookie` header when making HTTP requests to `example.com`, `www.example.com`, and
           `www.abc.example.com`. If the `Domain` attribute is not present, the client returns the cookie only for
           the domain to which the original request was made.

        *  Ensure that this attribute specifies the correct domain value. If the `Domain` attribute in the `Set-cookie`
           header does not include the domain to which the original request was made, the client or browser might reject
           the cookie. As specified in RFC 6265, the client accepts a cookie with the `Domain` attribute value `example.com`
           or `www.example.com` sent from `www.example.com`. It does not accept a cookie with the `Domain` attribute
           `abc.example.com` or `www.abc.example.com` sent from `www.example.com`.

        Example: `example.com`

        __ https://www.ietf.org/rfc/rfc6265.txt


        :return: The domain of this LBCookieSessionPersistenceConfigurationDetails.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """
        Sets the domain of this LBCookieSessionPersistenceConfigurationDetails.
        The domain in which the cookie is valid. The `Set-cookie` header inserted by the load balancer contains a
        domain attribute with the specified value.

        This attribute has no default value. If you do not specify a value, the load balancer does not insert the domain
        attribute into the `Set-cookie` header.

        **Notes:**

        *  `RFC 6265 - HTTP State Management Mechanism`__ describes client and
           browser behavior when the domain attribute is present or not present in the `Set-cookie` header.

           If the value of the `Domain` attribute is `example.com` in the `Set-cookie` header, the client includes
           the same cookie in the `Cookie` header when making HTTP requests to `example.com`, `www.example.com`, and
           `www.abc.example.com`. If the `Domain` attribute is not present, the client returns the cookie only for
           the domain to which the original request was made.

        *  Ensure that this attribute specifies the correct domain value. If the `Domain` attribute in the `Set-cookie`
           header does not include the domain to which the original request was made, the client or browser might reject
           the cookie. As specified in RFC 6265, the client accepts a cookie with the `Domain` attribute value `example.com`
           or `www.example.com` sent from `www.example.com`. It does not accept a cookie with the `Domain` attribute
           `abc.example.com` or `www.abc.example.com` sent from `www.example.com`.

        Example: `example.com`

        __ https://www.ietf.org/rfc/rfc6265.txt


        :param domain: The domain of this LBCookieSessionPersistenceConfigurationDetails.
        :type: str
        """
        self._domain = domain

    @property
    def path(self):
        """
        Gets the path of this LBCookieSessionPersistenceConfigurationDetails.
        The path in which the cookie is valid. The `Set-cookie header` inserted by the load balancer contains a `Path`
        attribute with the specified value.

        Clients include the cookie in an HTTP request only if the path portion of the request-uri matches, or is a
        subdirectory of, the cookie's `Path` attribute.

        The default value is `/`.

        Example: `/example`


        :return: The path of this LBCookieSessionPersistenceConfigurationDetails.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this LBCookieSessionPersistenceConfigurationDetails.
        The path in which the cookie is valid. The `Set-cookie header` inserted by the load balancer contains a `Path`
        attribute with the specified value.

        Clients include the cookie in an HTTP request only if the path portion of the request-uri matches, or is a
        subdirectory of, the cookie's `Path` attribute.

        The default value is `/`.

        Example: `/example`


        :param path: The path of this LBCookieSessionPersistenceConfigurationDetails.
        :type: str
        """
        self._path = path

    @property
    def max_age_in_seconds(self):
        """
        Gets the max_age_in_seconds of this LBCookieSessionPersistenceConfigurationDetails.
        The amount of time the cookie remains valid. The `Set-cookie` header inserted by the load balancer contains
        a `Max-Age` attribute with the specified value.

        The specified value must be at least one second. There is no default value for this attribute. If you do not
        specify a value, the load balancer does not include the `Max-Age` attribute in the `Set-cookie` header. In
        most cases, the client or browser retains the cookie until the current session ends, as defined by the client.

        Example: `3600`


        :return: The max_age_in_seconds of this LBCookieSessionPersistenceConfigurationDetails.
        :rtype: int
        """
        return self._max_age_in_seconds

    @max_age_in_seconds.setter
    def max_age_in_seconds(self, max_age_in_seconds):
        """
        Sets the max_age_in_seconds of this LBCookieSessionPersistenceConfigurationDetails.
        The amount of time the cookie remains valid. The `Set-cookie` header inserted by the load balancer contains
        a `Max-Age` attribute with the specified value.

        The specified value must be at least one second. There is no default value for this attribute. If you do not
        specify a value, the load balancer does not include the `Max-Age` attribute in the `Set-cookie` header. In
        most cases, the client or browser retains the cookie until the current session ends, as defined by the client.

        Example: `3600`


        :param max_age_in_seconds: The max_age_in_seconds of this LBCookieSessionPersistenceConfigurationDetails.
        :type: int
        """
        self._max_age_in_seconds = max_age_in_seconds

    @property
    def is_secure(self):
        """
        Gets the is_secure of this LBCookieSessionPersistenceConfigurationDetails.
        Whether the `Set-cookie` header should contain the `Secure` attribute. If `true`, the `Set-cookie` header
        inserted by the load balancer contains the `Secure` attribute, which directs the client or browser to send the
        cookie only using a secure protocol.

        **Note:** If you set this field to `true`, you cannot associate the corresponding backend set with an HTTP
        listener.

        Example: `true`


        :return: The is_secure of this LBCookieSessionPersistenceConfigurationDetails.
        :rtype: bool
        """
        return self._is_secure

    @is_secure.setter
    def is_secure(self, is_secure):
        """
        Sets the is_secure of this LBCookieSessionPersistenceConfigurationDetails.
        Whether the `Set-cookie` header should contain the `Secure` attribute. If `true`, the `Set-cookie` header
        inserted by the load balancer contains the `Secure` attribute, which directs the client or browser to send the
        cookie only using a secure protocol.

        **Note:** If you set this field to `true`, you cannot associate the corresponding backend set with an HTTP
        listener.

        Example: `true`


        :param is_secure: The is_secure of this LBCookieSessionPersistenceConfigurationDetails.
        :type: bool
        """
        self._is_secure = is_secure

    @property
    def is_http_only(self):
        """
        Gets the is_http_only of this LBCookieSessionPersistenceConfigurationDetails.
        Whether the `Set-cookie` header should contain the `HttpOnly` attribute. If `true`, the `Set-cookie` header
        inserted by the load balancer contains the `HttpOnly` attribute, which limits the scope of the cookie to HTTP
        requests. This attribute directs the client or browser to omit the cookie when providing access to cookies
        through non-HTTP APIs. For example, it restricts the cookie from JavaScript channels.

        Example: `true`


        :return: The is_http_only of this LBCookieSessionPersistenceConfigurationDetails.
        :rtype: bool
        """
        return self._is_http_only

    @is_http_only.setter
    def is_http_only(self, is_http_only):
        """
        Sets the is_http_only of this LBCookieSessionPersistenceConfigurationDetails.
        Whether the `Set-cookie` header should contain the `HttpOnly` attribute. If `true`, the `Set-cookie` header
        inserted by the load balancer contains the `HttpOnly` attribute, which limits the scope of the cookie to HTTP
        requests. This attribute directs the client or browser to omit the cookie when providing access to cookies
        through non-HTTP APIs. For example, it restricts the cookie from JavaScript channels.

        Example: `true`


        :param is_http_only: The is_http_only of this LBCookieSessionPersistenceConfigurationDetails.
        :type: bool
        """
        self._is_http_only = is_http_only

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .abstract_data_operation_config import AbstractDataOperationConfig
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class WriteOperationConfig(AbstractDataOperationConfig):
    """
    The information about the write operation.
    """

    #: A constant which can be used with the write_mode property of a WriteOperationConfig.
    #: This constant has a value of "OVERWRITE"
    WRITE_MODE_OVERWRITE = "OVERWRITE"

    #: A constant which can be used with the write_mode property of a WriteOperationConfig.
    #: This constant has a value of "APPEND"
    WRITE_MODE_APPEND = "APPEND"

    #: A constant which can be used with the write_mode property of a WriteOperationConfig.
    #: This constant has a value of "MERGE"
    WRITE_MODE_MERGE = "MERGE"

    #: A constant which can be used with the write_mode property of a WriteOperationConfig.
    #: This constant has a value of "IGNORE"
    WRITE_MODE_IGNORE = "IGNORE"

    def __init__(self, **kwargs):
        """
        Initializes a new WriteOperationConfig object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.WriteOperationConfig.model_type` attribute
        of this class is ``WRITE_OPERATION_CONFIG`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this WriteOperationConfig.
            Allowed values for this property are: "READ_OPERATION_CONFIG", "WRITE_OPERATION_CONFIG", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        :param key:
            The value to assign to the key property of this WriteOperationConfig.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this WriteOperationConfig.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this WriteOperationConfig.
        :type parent_ref: ParentReference

        :param operations:
            The value to assign to the operations property of this WriteOperationConfig.
        :type operations: list[PushDownOperation]

        :param data_format:
            The value to assign to the data_format property of this WriteOperationConfig.
        :type data_format: DataFormat

        :param partition_config:
            The value to assign to the partition_config property of this WriteOperationConfig.
        :type partition_config: PartitionConfig

        :param write_attribute:
            The value to assign to the write_attribute property of this WriteOperationConfig.
        :type write_attribute: AbstractWriteAttribute

        :param write_mode:
            The value to assign to the write_mode property of this WriteOperationConfig.
            Allowed values for this property are: "OVERWRITE", "APPEND", "MERGE", "IGNORE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type write_mode: str

        :param object_status:
            The value to assign to the object_status property of this WriteOperationConfig.
        :type object_status: int

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'operations': 'list[PushDownOperation]',
            'data_format': 'DataFormat',
            'partition_config': 'PartitionConfig',
            'write_attribute': 'AbstractWriteAttribute',
            'write_mode': 'str',
            'object_status': 'int'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'operations': 'operations',
            'data_format': 'dataFormat',
            'partition_config': 'partitionConfig',
            'write_attribute': 'writeAttribute',
            'write_mode': 'writeMode',
            'object_status': 'objectStatus'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._operations = None
        self._data_format = None
        self._partition_config = None
        self._write_attribute = None
        self._write_mode = None
        self._object_status = None
        self._model_type = 'WRITE_OPERATION_CONFIG'

    @property
    def key(self):
        """
        Gets the key of this WriteOperationConfig.
        The key of the object.


        :return: The key of this WriteOperationConfig.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this WriteOperationConfig.
        The key of the object.


        :param key: The key of this WriteOperationConfig.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this WriteOperationConfig.
        The model version of an object.


        :return: The model_version of this WriteOperationConfig.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this WriteOperationConfig.
        The model version of an object.


        :param model_version: The model_version of this WriteOperationConfig.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this WriteOperationConfig.

        :return: The parent_ref of this WriteOperationConfig.
        :rtype: ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this WriteOperationConfig.

        :param parent_ref: The parent_ref of this WriteOperationConfig.
        :type: ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def operations(self):
        """
        Gets the operations of this WriteOperationConfig.
        An array of operations.


        :return: The operations of this WriteOperationConfig.
        :rtype: list[PushDownOperation]
        """
        return self._operations

    @operations.setter
    def operations(self, operations):
        """
        Sets the operations of this WriteOperationConfig.
        An array of operations.


        :param operations: The operations of this WriteOperationConfig.
        :type: list[PushDownOperation]
        """
        self._operations = operations

    @property
    def data_format(self):
        """
        Gets the data_format of this WriteOperationConfig.

        :return: The data_format of this WriteOperationConfig.
        :rtype: DataFormat
        """
        return self._data_format

    @data_format.setter
    def data_format(self, data_format):
        """
        Sets the data_format of this WriteOperationConfig.

        :param data_format: The data_format of this WriteOperationConfig.
        :type: DataFormat
        """
        self._data_format = data_format

    @property
    def partition_config(self):
        """
        Gets the partition_config of this WriteOperationConfig.

        :return: The partition_config of this WriteOperationConfig.
        :rtype: PartitionConfig
        """
        return self._partition_config

    @partition_config.setter
    def partition_config(self, partition_config):
        """
        Sets the partition_config of this WriteOperationConfig.

        :param partition_config: The partition_config of this WriteOperationConfig.
        :type: PartitionConfig
        """
        self._partition_config = partition_config

    @property
    def write_attribute(self):
        """
        Gets the write_attribute of this WriteOperationConfig.

        :return: The write_attribute of this WriteOperationConfig.
        :rtype: AbstractWriteAttribute
        """
        return self._write_attribute

    @write_attribute.setter
    def write_attribute(self, write_attribute):
        """
        Sets the write_attribute of this WriteOperationConfig.

        :param write_attribute: The write_attribute of this WriteOperationConfig.
        :type: AbstractWriteAttribute
        """
        self._write_attribute = write_attribute

    @property
    def write_mode(self):
        """
        Gets the write_mode of this WriteOperationConfig.
        The mode for the write operation.

        Allowed values for this property are: "OVERWRITE", "APPEND", "MERGE", "IGNORE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The write_mode of this WriteOperationConfig.
        :rtype: str
        """
        return self._write_mode

    @write_mode.setter
    def write_mode(self, write_mode):
        """
        Sets the write_mode of this WriteOperationConfig.
        The mode for the write operation.


        :param write_mode: The write_mode of this WriteOperationConfig.
        :type: str
        """
        allowed_values = ["OVERWRITE", "APPEND", "MERGE", "IGNORE"]
        if not value_allowed_none_or_none_sentinel(write_mode, allowed_values):
            write_mode = 'UNKNOWN_ENUM_VALUE'
        self._write_mode = write_mode

    @property
    def object_status(self):
        """
        Gets the object_status of this WriteOperationConfig.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this WriteOperationConfig.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this WriteOperationConfig.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this WriteOperationConfig.
        :type: int
        """
        self._object_status = object_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .item import Item
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ActivityItem(Item):
    """
    Details about the ActivityItem object.
    """

    #: A constant which can be used with the activity_type property of a ActivityItem.
    #: This constant has a value of "NOTES"
    ACTIVITY_TYPE_NOTES = "NOTES"

    #: A constant which can be used with the activity_type property of a ActivityItem.
    #: This constant has a value of "PROBLEM_DESCRIPTION"
    ACTIVITY_TYPE_PROBLEM_DESCRIPTION = "PROBLEM_DESCRIPTION"

    #: A constant which can be used with the activity_type property of a ActivityItem.
    #: This constant has a value of "UPDATE"
    ACTIVITY_TYPE_UPDATE = "UPDATE"

    #: A constant which can be used with the activity_type property of a ActivityItem.
    #: This constant has a value of "CLOSE"
    ACTIVITY_TYPE_CLOSE = "CLOSE"

    #: A constant which can be used with the activity_author property of a ActivityItem.
    #: This constant has a value of "CUSTOMER"
    ACTIVITY_AUTHOR_CUSTOMER = "CUSTOMER"

    #: A constant which can be used with the activity_author property of a ActivityItem.
    #: This constant has a value of "ORACLE"
    ACTIVITY_AUTHOR_ORACLE = "ORACLE"

    def __init__(self, **kwargs):
        """
        Initializes a new ActivityItem object with values from keyword arguments. The default value of the :py:attr:`~oci.cims.models.ActivityItem.type` attribute
        of this class is ``activity`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param item_key:
            The value to assign to the item_key property of this ActivityItem.
        :type item_key: str

        :param name:
            The value to assign to the name property of this ActivityItem.
        :type name: str

        :param type:
            The value to assign to the type property of this ActivityItem.
        :type type: str

        :param category:
            The value to assign to the category property of this ActivityItem.
        :type category: Category

        :param sub_category:
            The value to assign to the sub_category property of this ActivityItem.
        :type sub_category: SubCategory

        :param issue_type:
            The value to assign to the issue_type property of this ActivityItem.
        :type issue_type: IssueType

        :param comments:
            The value to assign to the comments property of this ActivityItem.
        :type comments: str

        :param time_created:
            The value to assign to the time_created property of this ActivityItem.
        :type time_created: int

        :param time_updated:
            The value to assign to the time_updated property of this ActivityItem.
        :type time_updated: int

        :param activity_type:
            The value to assign to the activity_type property of this ActivityItem.
            Allowed values for this property are: "NOTES", "PROBLEM_DESCRIPTION", "UPDATE", "CLOSE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type activity_type: str

        :param activity_author:
            The value to assign to the activity_author property of this ActivityItem.
            Allowed values for this property are: "CUSTOMER", "ORACLE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type activity_author: str

        """
        self.swagger_types = {
            'item_key': 'str',
            'name': 'str',
            'type': 'str',
            'category': 'Category',
            'sub_category': 'SubCategory',
            'issue_type': 'IssueType',
            'comments': 'str',
            'time_created': 'int',
            'time_updated': 'int',
            'activity_type': 'str',
            'activity_author': 'str'
        }

        self.attribute_map = {
            'item_key': 'itemKey',
            'name': 'name',
            'type': 'type',
            'category': 'category',
            'sub_category': 'subCategory',
            'issue_type': 'issueType',
            'comments': 'comments',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'activity_type': 'activityType',
            'activity_author': 'activityAuthor'
        }

        self._item_key = None
        self._name = None
        self._type = None
        self._category = None
        self._sub_category = None
        self._issue_type = None
        self._comments = None
        self._time_created = None
        self._time_updated = None
        self._activity_type = None
        self._activity_author = None
        self._type = 'activity'

    @property
    def comments(self):
        """
        Gets the comments of this ActivityItem.
        Comments added with the activity on the support ticket.


        :return: The comments of this ActivityItem.
        :rtype: str
        """
        return self._comments

    @comments.setter
    def comments(self, comments):
        """
        Sets the comments of this ActivityItem.
        Comments added with the activity on the support ticket.


        :param comments: The comments of this ActivityItem.
        :type: str
        """
        self._comments = comments

    @property
    def time_created(self):
        """
        Gets the time_created of this ActivityItem.
        The time when the activity was created, in milliseconds since epoch time.


        :return: The time_created of this ActivityItem.
        :rtype: int
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ActivityItem.
        The time when the activity was created, in milliseconds since epoch time.


        :param time_created: The time_created of this ActivityItem.
        :type: int
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this ActivityItem.
        The time when the activity was updated, in milliseconds since epoch time.


        :return: The time_updated of this ActivityItem.
        :rtype: int
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this ActivityItem.
        The time when the activity was updated, in milliseconds since epoch time.


        :param time_updated: The time_updated of this ActivityItem.
        :type: int
        """
        self._time_updated = time_updated

    @property
    def activity_type(self):
        """
        Gets the activity_type of this ActivityItem.
        The type of activity occuring on the support ticket.

        Allowed values for this property are: "NOTES", "PROBLEM_DESCRIPTION", "UPDATE", "CLOSE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The activity_type of this ActivityItem.
        :rtype: str
        """
        return self._activity_type

    @activity_type.setter
    def activity_type(self, activity_type):
        """
        Sets the activity_type of this ActivityItem.
        The type of activity occuring on the support ticket.


        :param activity_type: The activity_type of this ActivityItem.
        :type: str
        """
        allowed_values = ["NOTES", "PROBLEM_DESCRIPTION", "UPDATE", "CLOSE"]
        if not value_allowed_none_or_none_sentinel(activity_type, allowed_values):
            activity_type = 'UNKNOWN_ENUM_VALUE'
        self._activity_type = activity_type

    @property
    def activity_author(self):
        """
        Gets the activity_author of this ActivityItem.
        The person who updates the activity on the support ticket.

        Allowed values for this property are: "CUSTOMER", "ORACLE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The activity_author of this ActivityItem.
        :rtype: str
        """
        return self._activity_author

    @activity_author.setter
    def activity_author(self, activity_author):
        """
        Sets the activity_author of this ActivityItem.
        The person who updates the activity on the support ticket.


        :param activity_author: The activity_author of this ActivityItem.
        :type: str
        """
        allowed_values = ["CUSTOMER", "ORACLE"]
        if not value_allowed_none_or_none_sentinel(activity_author, allowed_values):
            activity_author = 'UNKNOWN_ENUM_VALUE'
        self._activity_author = activity_author

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AttachChildSoftwareSourceToManagedInstanceDetails(object):
    """
    Information for attaching a software source to a managed instance
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AttachChildSoftwareSourceToManagedInstanceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param software_source_id:
            The value to assign to the software_source_id property of this AttachChildSoftwareSourceToManagedInstanceDetails.
        :type software_source_id: str

        """
        self.swagger_types = {
            'software_source_id': 'str'
        }

        self.attribute_map = {
            'software_source_id': 'softwareSourceId'
        }

        self._software_source_id = None

    @property
    def software_source_id(self):
        """
        **[Required]** Gets the software_source_id of this AttachChildSoftwareSourceToManagedInstanceDetails.
        OCID for the Software Source


        :return: The software_source_id of this AttachChildSoftwareSourceToManagedInstanceDetails.
        :rtype: str
        """
        return self._software_source_id

    @software_source_id.setter
    def software_source_id(self, software_source_id):
        """
        Sets the software_source_id of this AttachChildSoftwareSourceToManagedInstanceDetails.
        OCID for the Software Source


        :param software_source_id: The software_source_id of this AttachChildSoftwareSourceToManagedInstanceDetails.
        :type: str
        """
        self._software_source_id = software_source_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Datapoint(object):
    """
    Metric value for a specific timestamp.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Datapoint object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param timestamp:
            The value to assign to the timestamp property of this Datapoint.
        :type timestamp: datetime

        :param value:
            The value to assign to the value property of this Datapoint.
        :type value: float

        :param count:
            The value to assign to the count property of this Datapoint.
        :type count: int

        """
        self.swagger_types = {
            'timestamp': 'datetime',
            'value': 'float',
            'count': 'int'
        }

        self.attribute_map = {
            'timestamp': 'timestamp',
            'value': 'value',
            'count': 'count'
        }

        self._timestamp = None
        self._value = None
        self._count = None

    @property
    def timestamp(self):
        """
        **[Required]** Gets the timestamp of this Datapoint.
        Timestamp for this metric value. Format defined by RFC3339.

        Example: `2019-02-01T01:02:29.600Z`


        :return: The timestamp of this Datapoint.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this Datapoint.
        Timestamp for this metric value. Format defined by RFC3339.

        Example: `2019-02-01T01:02:29.600Z`


        :param timestamp: The timestamp of this Datapoint.
        :type: datetime
        """
        self._timestamp = timestamp

    @property
    def value(self):
        """
        **[Required]** Gets the value of this Datapoint.
        Numeric value of the metric.

        Example: `10.23`


        :return: The value of this Datapoint.
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this Datapoint.
        Numeric value of the metric.

        Example: `10.23`


        :param value: The value of this Datapoint.
        :type: float
        """
        self._value = value

    @property
    def count(self):
        """
        Gets the count of this Datapoint.
        The number of occurrences of the associated value in the set of data.

        Default is 1. Value must be greater than zero.


        :return: The count of this Datapoint.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this Datapoint.
        The number of occurrences of the associated value in the set of data.

        Default is 1. Value must be greater than zero.


        :param count: The count of this Datapoint.
        :type: int
        """
        self._count = count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class StackResourceDriftSummary(object):
    """
    Drift status details for the indicated resource and stack. Includes actual and expected (defined) properties.
    """

    #: A constant which can be used with the resource_drift_status property of a StackResourceDriftSummary.
    #: This constant has a value of "NOT_CHECKED"
    RESOURCE_DRIFT_STATUS_NOT_CHECKED = "NOT_CHECKED"

    #: A constant which can be used with the resource_drift_status property of a StackResourceDriftSummary.
    #: This constant has a value of "IN_SYNC"
    RESOURCE_DRIFT_STATUS_IN_SYNC = "IN_SYNC"

    #: A constant which can be used with the resource_drift_status property of a StackResourceDriftSummary.
    #: This constant has a value of "MODIFIED"
    RESOURCE_DRIFT_STATUS_MODIFIED = "MODIFIED"

    #: A constant which can be used with the resource_drift_status property of a StackResourceDriftSummary.
    #: This constant has a value of "DELETED"
    RESOURCE_DRIFT_STATUS_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new StackResourceDriftSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param stack_id:
            The value to assign to the stack_id property of this StackResourceDriftSummary.
        :type stack_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this StackResourceDriftSummary.
        :type compartment_id: str

        :param resource_name:
            The value to assign to the resource_name property of this StackResourceDriftSummary.
        :type resource_name: str

        :param resource_id:
            The value to assign to the resource_id property of this StackResourceDriftSummary.
        :type resource_id: str

        :param resource_type:
            The value to assign to the resource_type property of this StackResourceDriftSummary.
        :type resource_type: str

        :param resource_drift_status:
            The value to assign to the resource_drift_status property of this StackResourceDriftSummary.
            Allowed values for this property are: "NOT_CHECKED", "IN_SYNC", "MODIFIED", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type resource_drift_status: str

        :param actual_properties:
            The value to assign to the actual_properties property of this StackResourceDriftSummary.
        :type actual_properties: dict(str, str)

        :param expected_properties:
            The value to assign to the expected_properties property of this StackResourceDriftSummary.
        :type expected_properties: dict(str, str)

        :param time_drift_checked:
            The value to assign to the time_drift_checked property of this StackResourceDriftSummary.
        :type time_drift_checked: datetime

        """
        self.swagger_types = {
            'stack_id': 'str',
            'compartment_id': 'str',
            'resource_name': 'str',
            'resource_id': 'str',
            'resource_type': 'str',
            'resource_drift_status': 'str',
            'actual_properties': 'dict(str, str)',
            'expected_properties': 'dict(str, str)',
            'time_drift_checked': 'datetime'
        }

        self.attribute_map = {
            'stack_id': 'stackId',
            'compartment_id': 'compartmentId',
            'resource_name': 'resourceName',
            'resource_id': 'resourceId',
            'resource_type': 'resourceType',
            'resource_drift_status': 'resourceDriftStatus',
            'actual_properties': 'actualProperties',
            'expected_properties': 'expectedProperties',
            'time_drift_checked': 'timeDriftChecked'
        }

        self._stack_id = None
        self._compartment_id = None
        self._resource_name = None
        self._resource_id = None
        self._resource_type = None
        self._resource_drift_status = None
        self._actual_properties = None
        self._expected_properties = None
        self._time_drift_checked = None

    @property
    def stack_id(self):
        """
        Gets the stack_id of this StackResourceDriftSummary.
        The `OCID`__ of the stack.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The stack_id of this StackResourceDriftSummary.
        :rtype: str
        """
        return self._stack_id

    @stack_id.setter
    def stack_id(self, stack_id):
        """
        Sets the stack_id of this StackResourceDriftSummary.
        The `OCID`__ of the stack.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param stack_id: The stack_id of this StackResourceDriftSummary.
        :type: str
        """
        self._stack_id = stack_id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this StackResourceDriftSummary.
        The `OCID`__ of the compartment where the stack is located.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this StackResourceDriftSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this StackResourceDriftSummary.
        The `OCID`__ of the compartment where the stack is located.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this StackResourceDriftSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def resource_name(self):
        """
        Gets the resource_name of this StackResourceDriftSummary.
        The name of the resource as defined in the stack.


        :return: The resource_name of this StackResourceDriftSummary.
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """
        Sets the resource_name of this StackResourceDriftSummary.
        The name of the resource as defined in the stack.


        :param resource_name: The resource_name of this StackResourceDriftSummary.
        :type: str
        """
        self._resource_name = resource_name

    @property
    def resource_id(self):
        """
        Gets the resource_id of this StackResourceDriftSummary.
        The `OCID`__ of the resource provisioned by Terraform.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The resource_id of this StackResourceDriftSummary.
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """
        Sets the resource_id of this StackResourceDriftSummary.
        The `OCID`__ of the resource provisioned by Terraform.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param resource_id: The resource_id of this StackResourceDriftSummary.
        :type: str
        """
        self._resource_id = resource_id

    @property
    def resource_type(self):
        """
        Gets the resource_type of this StackResourceDriftSummary.
        The provider resource type.
        Must be supported by the `Oracle Cloud Infrastructure provider`__.
        Example: `oci_core_instance`

        __ https://www.terraform.io/docs/providers/oci/index.html


        :return: The resource_type of this StackResourceDriftSummary.
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """
        Sets the resource_type of this StackResourceDriftSummary.
        The provider resource type.
        Must be supported by the `Oracle Cloud Infrastructure provider`__.
        Example: `oci_core_instance`

        __ https://www.terraform.io/docs/providers/oci/index.html


        :param resource_type: The resource_type of this StackResourceDriftSummary.
        :type: str
        """
        self._resource_type = resource_type

    @property
    def resource_drift_status(self):
        """
        Gets the resource_drift_status of this StackResourceDriftSummary.
        The drift status of the resource.
        A drift status value indicates whether or not the actual state of the resource differs from the expected (defined) state for that resource.

        Allowed values for this property are: "NOT_CHECKED", "IN_SYNC", "MODIFIED", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The resource_drift_status of this StackResourceDriftSummary.
        :rtype: str
        """
        return self._resource_drift_status

    @resource_drift_status.setter
    def resource_drift_status(self, resource_drift_status):
        """
        Sets the resource_drift_status of this StackResourceDriftSummary.
        The drift status of the resource.
        A drift status value indicates whether or not the actual state of the resource differs from the expected (defined) state for that resource.


        :param resource_drift_status: The resource_drift_status of this StackResourceDriftSummary.
        :type: str
        """
        allowed_values = ["NOT_CHECKED", "IN_SYNC", "MODIFIED", "DELETED"]
        if not value_allowed_none_or_none_sentinel(resource_drift_status, allowed_values):
            resource_drift_status = 'UNKNOWN_ENUM_VALUE'
        self._resource_drift_status = resource_drift_status

    @property
    def actual_properties(self):
        """
        Gets the actual_properties of this StackResourceDriftSummary.
        Actual values of properties that the stack defines for the indicated resource.
        Each property and value is provided as a key-value pair.
        The following example shows actual values for the resource's display name and server type:
        `{\"display_name\": \"tf-default-dhcp-options-new\", \"options.0.server_type\": \"VcnLocalPlusInternet\"}`


        :return: The actual_properties of this StackResourceDriftSummary.
        :rtype: dict(str, str)
        """
        return self._actual_properties

    @actual_properties.setter
    def actual_properties(self, actual_properties):
        """
        Sets the actual_properties of this StackResourceDriftSummary.
        Actual values of properties that the stack defines for the indicated resource.
        Each property and value is provided as a key-value pair.
        The following example shows actual values for the resource's display name and server type:
        `{\"display_name\": \"tf-default-dhcp-options-new\", \"options.0.server_type\": \"VcnLocalPlusInternet\"}`


        :param actual_properties: The actual_properties of this StackResourceDriftSummary.
        :type: dict(str, str)
        """
        self._actual_properties = actual_properties

    @property
    def expected_properties(self):
        """
        Gets the expected_properties of this StackResourceDriftSummary.
        Expected values of properties that the stack defines for the indicated resource.
        Each property and value is provided as a key-value pair.
        The following example shows expected (defined) values for the resource's display name and server type:
        `{\"display_name\": \"tf-default-dhcp-options\", \"options.0.server_type\": \"VcnLocalPlusInternet\"}`


        :return: The expected_properties of this StackResourceDriftSummary.
        :rtype: dict(str, str)
        """
        return self._expected_properties

    @expected_properties.setter
    def expected_properties(self, expected_properties):
        """
        Sets the expected_properties of this StackResourceDriftSummary.
        Expected values of properties that the stack defines for the indicated resource.
        Each property and value is provided as a key-value pair.
        The following example shows expected (defined) values for the resource's display name and server type:
        `{\"display_name\": \"tf-default-dhcp-options\", \"options.0.server_type\": \"VcnLocalPlusInternet\"}`


        :param expected_properties: The expected_properties of this StackResourceDriftSummary.
        :type: dict(str, str)
        """
        self._expected_properties = expected_properties

    @property
    def time_drift_checked(self):
        """
        Gets the time_drift_checked of this StackResourceDriftSummary.
        The date and time when the drift detection was executed.
        Format is defined by RFC3339.
        Example: `2020-01-25T21:10:29.600Z`


        :return: The time_drift_checked of this StackResourceDriftSummary.
        :rtype: datetime
        """
        return self._time_drift_checked

    @time_drift_checked.setter
    def time_drift_checked(self, time_drift_checked):
        """
        Sets the time_drift_checked of this StackResourceDriftSummary.
        The date and time when the drift detection was executed.
        Format is defined by RFC3339.
        Example: `2020-01-25T21:10:29.600Z`


        :param time_drift_checked: The time_drift_checked of this StackResourceDriftSummary.
        :type: datetime
        """
        self._time_drift_checked = time_drift_checked

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .steering_policy_rule import SteeringPolicyRule
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SteeringPolicyPriorityRule(SteeringPolicyRule):
    """
    SteeringPolicyPriorityRule model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SteeringPolicyPriorityRule object with values from keyword arguments. The default value of the :py:attr:`~oci.dns.models.SteeringPolicyPriorityRule.rule_type` attribute
        of this class is ``PRIORITY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this SteeringPolicyPriorityRule.
        :type description: str

        :param rule_type:
            The value to assign to the rule_type property of this SteeringPolicyPriorityRule.
            Allowed values for this property are: "FILTER", "HEALTH", "WEIGHTED", "PRIORITY", "LIMIT"
        :type rule_type: str

        :param cases:
            The value to assign to the cases property of this SteeringPolicyPriorityRule.
        :type cases: list[SteeringPolicyPriorityRuleCase]

        :param default_answer_data:
            The value to assign to the default_answer_data property of this SteeringPolicyPriorityRule.
        :type default_answer_data: list[SteeringPolicyPriorityAnswerData]

        """
        self.swagger_types = {
            'description': 'str',
            'rule_type': 'str',
            'cases': 'list[SteeringPolicyPriorityRuleCase]',
            'default_answer_data': 'list[SteeringPolicyPriorityAnswerData]'
        }

        self.attribute_map = {
            'description': 'description',
            'rule_type': 'ruleType',
            'cases': 'cases',
            'default_answer_data': 'defaultAnswerData'
        }

        self._description = None
        self._rule_type = None
        self._cases = None
        self._default_answer_data = None
        self._rule_type = 'PRIORITY'

    @property
    def cases(self):
        """
        Gets the cases of this SteeringPolicyPriorityRule.
        An array of `caseConditions`. A rule may optionally include a sequence of cases defining alternate
        configurations for how it should behave during processing for any given DNS query. When a rule has
        no sequence of `cases`, it is always evaluated with the same configuration during processing. When
        a rule has an empty sequence of `cases`, it is always ignored during processing. When a rule has a
        non-empty sequence of `cases`, its behavior during processing is configured by the first matching
        `case` in the sequence. When a rule has no matching cases the rule is ignored. A rule case with no
        `caseCondition` always matches. A rule case with a `caseCondition` matches only when that expression
        evaluates to true for the given query.


        :return: The cases of this SteeringPolicyPriorityRule.
        :rtype: list[SteeringPolicyPriorityRuleCase]
        """
        return self._cases

    @cases.setter
    def cases(self, cases):
        """
        Sets the cases of this SteeringPolicyPriorityRule.
        An array of `caseConditions`. A rule may optionally include a sequence of cases defining alternate
        configurations for how it should behave during processing for any given DNS query. When a rule has
        no sequence of `cases`, it is always evaluated with the same configuration during processing. When
        a rule has an empty sequence of `cases`, it is always ignored during processing. When a rule has a
        non-empty sequence of `cases`, its behavior during processing is configured by the first matching
        `case` in the sequence. When a rule has no matching cases the rule is ignored. A rule case with no
        `caseCondition` always matches. A rule case with a `caseCondition` matches only when that expression
        evaluates to true for the given query.


        :param cases: The cases of this SteeringPolicyPriorityRule.
        :type: list[SteeringPolicyPriorityRuleCase]
        """
        self._cases = cases

    @property
    def default_answer_data(self):
        """
        Gets the default_answer_data of this SteeringPolicyPriorityRule.
        Defines a default set of answer conditions and values that are applied to an answer when
        `cases` is not defined for the rule or a matching case does not have any matching
        `answerCondition`s in its `answerData`. `defaultAnswerData` is not applied if `cases` is
        defined and there are no matching cases. In this scenario, the next rule will be processed.


        :return: The default_answer_data of this SteeringPolicyPriorityRule.
        :rtype: list[SteeringPolicyPriorityAnswerData]
        """
        return self._default_answer_data

    @default_answer_data.setter
    def default_answer_data(self, default_answer_data):
        """
        Sets the default_answer_data of this SteeringPolicyPriorityRule.
        Defines a default set of answer conditions and values that are applied to an answer when
        `cases` is not defined for the rule or a matching case does not have any matching
        `answerCondition`s in its `answerData`. `defaultAnswerData` is not applied if `cases` is
        defined and there are no matching cases. In this scenario, the next rule will be processed.


        :param default_answer_data: The default_answer_data of this SteeringPolicyPriorityRule.
        :type: list[SteeringPolicyPriorityAnswerData]
        """
        self._default_answer_data = default_answer_data

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class StepInfo(object):
    """
    StepInfo
    """

    def __init__(self, **kwargs):
        """
        Initializes a new StepInfo object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param input_sequence_current_match:
            The value to assign to the input_sequence_current_match property of this StepInfo.
        :type input_sequence_current_match: str

        :param regex_engine_class_name:
            The value to assign to the regex_engine_class_name property of this StepInfo.
        :type regex_engine_class_name: str

        :param step_count:
            The value to assign to the step_count property of this StepInfo.
        :type step_count: int

        """
        self.swagger_types = {
            'input_sequence_current_match': 'str',
            'regex_engine_class_name': 'str',
            'step_count': 'int'
        }

        self.attribute_map = {
            'input_sequence_current_match': 'inputSequenceCurrentMatch',
            'regex_engine_class_name': 'regexEngineClassName',
            'step_count': 'stepCount'
        }

        self._input_sequence_current_match = None
        self._regex_engine_class_name = None
        self._step_count = None

    @property
    def input_sequence_current_match(self):
        """
        Gets the input_sequence_current_match of this StepInfo.
        inputSequenceCurrentMatch


        :return: The input_sequence_current_match of this StepInfo.
        :rtype: str
        """
        return self._input_sequence_current_match

    @input_sequence_current_match.setter
    def input_sequence_current_match(self, input_sequence_current_match):
        """
        Sets the input_sequence_current_match of this StepInfo.
        inputSequenceCurrentMatch


        :param input_sequence_current_match: The input_sequence_current_match of this StepInfo.
        :type: str
        """
        self._input_sequence_current_match = input_sequence_current_match

    @property
    def regex_engine_class_name(self):
        """
        Gets the regex_engine_class_name of this StepInfo.
        regexEngineClassName


        :return: The regex_engine_class_name of this StepInfo.
        :rtype: str
        """
        return self._regex_engine_class_name

    @regex_engine_class_name.setter
    def regex_engine_class_name(self, regex_engine_class_name):
        """
        Sets the regex_engine_class_name of this StepInfo.
        regexEngineClassName


        :param regex_engine_class_name: The regex_engine_class_name of this StepInfo.
        :type: str
        """
        self._regex_engine_class_name = regex_engine_class_name

    @property
    def step_count(self):
        """
        Gets the step_count of this StepInfo.
        stepCount


        :return: The step_count of this StepInfo.
        :rtype: int
        """
        return self._step_count

    @step_count.setter
    def step_count(self, step_count):
        """
        Sets the step_count of this StepInfo.
        stepCount


        :param step_count: The step_count of this StepInfo.
        :type: int
        """
        self._step_count = step_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateApplianceExportJobDetails(object):
    """
    UpdateApplianceExportJobDetails model.
    """

    #: A constant which can be used with the lifecycle_state property of a UpdateApplianceExportJobDetails.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a UpdateApplianceExportJobDetails.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a UpdateApplianceExportJobDetails.
    #: This constant has a value of "INPROGRESS"
    LIFECYCLE_STATE_INPROGRESS = "INPROGRESS"

    #: A constant which can be used with the lifecycle_state property of a UpdateApplianceExportJobDetails.
    #: This constant has a value of "SUCCEEDED"
    LIFECYCLE_STATE_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the lifecycle_state property of a UpdateApplianceExportJobDetails.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a UpdateApplianceExportJobDetails.
    #: This constant has a value of "CANCELLED"
    LIFECYCLE_STATE_CANCELLED = "CANCELLED"

    #: A constant which can be used with the lifecycle_state property of a UpdateApplianceExportJobDetails.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateApplianceExportJobDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param bucket_name:
            The value to assign to the bucket_name property of this UpdateApplianceExportJobDetails.
        :type bucket_name: str

        :param prefix:
            The value to assign to the prefix property of this UpdateApplianceExportJobDetails.
        :type prefix: str

        :param range_start:
            The value to assign to the range_start property of this UpdateApplianceExportJobDetails.
        :type range_start: str

        :param range_end:
            The value to assign to the range_end property of this UpdateApplianceExportJobDetails.
        :type range_end: str

        :param display_name:
            The value to assign to the display_name property of this UpdateApplianceExportJobDetails.
        :type display_name: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this UpdateApplianceExportJobDetails.
            Allowed values for this property are: "CREATING", "ACTIVE", "INPROGRESS", "SUCCEEDED", "FAILED", "CANCELLED", "DELETED"
        :type lifecycle_state: str

        :param lifecycle_state_details:
            The value to assign to the lifecycle_state_details property of this UpdateApplianceExportJobDetails.
        :type lifecycle_state_details: str

        :param manifest_file:
            The value to assign to the manifest_file property of this UpdateApplianceExportJobDetails.
        :type manifest_file: str

        :param manifest_md5:
            The value to assign to the manifest_md5 property of this UpdateApplianceExportJobDetails.
        :type manifest_md5: str

        :param number_of_objects:
            The value to assign to the number_of_objects property of this UpdateApplianceExportJobDetails.
        :type number_of_objects: str

        :param total_size_in_bytes:
            The value to assign to the total_size_in_bytes property of this UpdateApplianceExportJobDetails.
        :type total_size_in_bytes: str

        :param first_object:
            The value to assign to the first_object property of this UpdateApplianceExportJobDetails.
        :type first_object: str

        :param last_object:
            The value to assign to the last_object property of this UpdateApplianceExportJobDetails.
        :type last_object: str

        :param next_object:
            The value to assign to the next_object property of this UpdateApplianceExportJobDetails.
        :type next_object: str

        :param customer_shipping_address:
            The value to assign to the customer_shipping_address property of this UpdateApplianceExportJobDetails.
        :type customer_shipping_address: ShippingAddress

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateApplianceExportJobDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateApplianceExportJobDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'bucket_name': 'str',
            'prefix': 'str',
            'range_start': 'str',
            'range_end': 'str',
            'display_name': 'str',
            'lifecycle_state': 'str',
            'lifecycle_state_details': 'str',
            'manifest_file': 'str',
            'manifest_md5': 'str',
            'number_of_objects': 'str',
            'total_size_in_bytes': 'str',
            'first_object': 'str',
            'last_object': 'str',
            'next_object': 'str',
            'customer_shipping_address': 'ShippingAddress',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'bucket_name': 'bucketName',
            'prefix': 'prefix',
            'range_start': 'rangeStart',
            'range_end': 'rangeEnd',
            'display_name': 'displayName',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_state_details': 'lifecycleStateDetails',
            'manifest_file': 'manifestFile',
            'manifest_md5': 'manifestMd5',
            'number_of_objects': 'numberOfObjects',
            'total_size_in_bytes': 'totalSizeInBytes',
            'first_object': 'firstObject',
            'last_object': 'lastObject',
            'next_object': 'nextObject',
            'customer_shipping_address': 'customerShippingAddress',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._bucket_name = None
        self._prefix = None
        self._range_start = None
        self._range_end = None
        self._display_name = None
        self._lifecycle_state = None
        self._lifecycle_state_details = None
        self._manifest_file = None
        self._manifest_md5 = None
        self._number_of_objects = None
        self._total_size_in_bytes = None
        self._first_object = None
        self._last_object = None
        self._next_object = None
        self._customer_shipping_address = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def bucket_name(self):
        """
        Gets the bucket_name of this UpdateApplianceExportJobDetails.

        :return: The bucket_name of this UpdateApplianceExportJobDetails.
        :rtype: str
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        """
        Sets the bucket_name of this UpdateApplianceExportJobDetails.

        :param bucket_name: The bucket_name of this UpdateApplianceExportJobDetails.
        :type: str
        """
        self._bucket_name = bucket_name

    @property
    def prefix(self):
        """
        Gets the prefix of this UpdateApplianceExportJobDetails.
        List of objects with names matching this prefix would be part of this export job.


        :return: The prefix of this UpdateApplianceExportJobDetails.
        :rtype: str
        """
        return self._prefix

    @prefix.setter
    def prefix(self, prefix):
        """
        Sets the prefix of this UpdateApplianceExportJobDetails.
        List of objects with names matching this prefix would be part of this export job.


        :param prefix: The prefix of this UpdateApplianceExportJobDetails.
        :type: str
        """
        self._prefix = prefix

    @property
    def range_start(self):
        """
        Gets the range_start of this UpdateApplianceExportJobDetails.
        Object names returned by a list query must be greater or equal to this parameter.


        :return: The range_start of this UpdateApplianceExportJobDetails.
        :rtype: str
        """
        return self._range_start

    @range_start.setter
    def range_start(self, range_start):
        """
        Sets the range_start of this UpdateApplianceExportJobDetails.
        Object names returned by a list query must be greater or equal to this parameter.


        :param range_start: The range_start of this UpdateApplianceExportJobDetails.
        :type: str
        """
        self._range_start = range_start

    @property
    def range_end(self):
        """
        Gets the range_end of this UpdateApplianceExportJobDetails.
        Object names returned by a list query must be strictly less than this parameter.


        :return: The range_end of this UpdateApplianceExportJobDetails.
        :rtype: str
        """
        return self._range_end

    @range_end.setter
    def range_end(self, range_end):
        """
        Sets the range_end of this UpdateApplianceExportJobDetails.
        Object names returned by a list query must be strictly less than this parameter.


        :param range_end: The range_end of this UpdateApplianceExportJobDetails.
        :type: str
        """
        self._range_end = range_end

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateApplianceExportJobDetails.

        :return: The display_name of this UpdateApplianceExportJobDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateApplianceExportJobDetails.

        :param display_name: The display_name of this UpdateApplianceExportJobDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this UpdateApplianceExportJobDetails.
        Allowed values for this property are: "CREATING", "ACTIVE", "INPROGRESS", "SUCCEEDED", "FAILED", "CANCELLED", "DELETED"


        :return: The lifecycle_state of this UpdateApplianceExportJobDetails.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this UpdateApplianceExportJobDetails.

        :param lifecycle_state: The lifecycle_state of this UpdateApplianceExportJobDetails.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INPROGRESS", "SUCCEEDED", "FAILED", "CANCELLED", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            raise ValueError(
                "Invalid value for `lifecycle_state`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_state_details(self):
        """
        Gets the lifecycle_state_details of this UpdateApplianceExportJobDetails.
        A property that can contain details on the lifecycle.


        :return: The lifecycle_state_details of this UpdateApplianceExportJobDetails.
        :rtype: str
        """
        return self._lifecycle_state_details

    @lifecycle_state_details.setter
    def lifecycle_state_details(self, lifecycle_state_details):
        """
        Sets the lifecycle_state_details of this UpdateApplianceExportJobDetails.
        A property that can contain details on the lifecycle.


        :param lifecycle_state_details: The lifecycle_state_details of this UpdateApplianceExportJobDetails.
        :type: str
        """
        self._lifecycle_state_details = lifecycle_state_details

    @property
    def manifest_file(self):
        """
        Gets the manifest_file of this UpdateApplianceExportJobDetails.
        Manifest File associated with this export job.


        :return: The manifest_file of this UpdateApplianceExportJobDetails.
        :rtype: str
        """
        return self._manifest_file

    @manifest_file.setter
    def manifest_file(self, manifest_file):
        """
        Sets the manifest_file of this UpdateApplianceExportJobDetails.
        Manifest File associated with this export job.


        :param manifest_file: The manifest_file of this UpdateApplianceExportJobDetails.
        :type: str
        """
        self._manifest_file = manifest_file

    @property
    def manifest_md5(self):
        """
        Gets the manifest_md5 of this UpdateApplianceExportJobDetails.
        md5 digest of the manifest file.


        :return: The manifest_md5 of this UpdateApplianceExportJobDetails.
        :rtype: str
        """
        return self._manifest_md5

    @manifest_md5.setter
    def manifest_md5(self, manifest_md5):
        """
        Sets the manifest_md5 of this UpdateApplianceExportJobDetails.
        md5 digest of the manifest file.


        :param manifest_md5: The manifest_md5 of this UpdateApplianceExportJobDetails.
        :type: str
        """
        self._manifest_md5 = manifest_md5

    @property
    def number_of_objects(self):
        """
        Gets the number_of_objects of this UpdateApplianceExportJobDetails.
        Total number of objects that are exported in this job.


        :return: The number_of_objects of this UpdateApplianceExportJobDetails.
        :rtype: str
        """
        return self._number_of_objects

    @number_of_objects.setter
    def number_of_objects(self, number_of_objects):
        """
        Sets the number_of_objects of this UpdateApplianceExportJobDetails.
        Total number of objects that are exported in this job.


        :param number_of_objects: The number_of_objects of this UpdateApplianceExportJobDetails.
        :type: str
        """
        self._number_of_objects = number_of_objects

    @property
    def total_size_in_bytes(self):
        """
        Gets the total_size_in_bytes of this UpdateApplianceExportJobDetails.
        Total size of objects in Bytes that are exported in this job.


        :return: The total_size_in_bytes of this UpdateApplianceExportJobDetails.
        :rtype: str
        """
        return self._total_size_in_bytes

    @total_size_in_bytes.setter
    def total_size_in_bytes(self, total_size_in_bytes):
        """
        Sets the total_size_in_bytes of this UpdateApplianceExportJobDetails.
        Total size of objects in Bytes that are exported in this job.


        :param total_size_in_bytes: The total_size_in_bytes of this UpdateApplianceExportJobDetails.
        :type: str
        """
        self._total_size_in_bytes = total_size_in_bytes

    @property
    def first_object(self):
        """
        Gets the first_object of this UpdateApplianceExportJobDetails.
        First object in the list of objects that are exported in this job.


        :return: The first_object of this UpdateApplianceExportJobDetails.
        :rtype: str
        """
        return self._first_object

    @first_object.setter
    def first_object(self, first_object):
        """
        Sets the first_object of this UpdateApplianceExportJobDetails.
        First object in the list of objects that are exported in this job.


        :param first_object: The first_object of this UpdateApplianceExportJobDetails.
        :type: str
        """
        self._first_object = first_object

    @property
    def last_object(self):
        """
        Gets the last_object of this UpdateApplianceExportJobDetails.
        Last object in the list of objects that are exported in this job.


        :return: The last_object of this UpdateApplianceExportJobDetails.
        :rtype: str
        """
        return self._last_object

    @last_object.setter
    def last_object(self, last_object):
        """
        Sets the last_object of this UpdateApplianceExportJobDetails.
        Last object in the list of objects that are exported in this job.


        :param last_object: The last_object of this UpdateApplianceExportJobDetails.
        :type: str
        """
        self._last_object = last_object

    @property
    def next_object(self):
        """
        Gets the next_object of this UpdateApplianceExportJobDetails.
        First object from which the next potential export job could start.


        :return: The next_object of this UpdateApplianceExportJobDetails.
        :rtype: str
        """
        return self._next_object

    @next_object.setter
    def next_object(self, next_object):
        """
        Sets the next_object of this UpdateApplianceExportJobDetails.
        First object from which the next potential export job could start.


        :param next_object: The next_object of this UpdateApplianceExportJobDetails.
        :type: str
        """
        self._next_object = next_object

    @property
    def customer_shipping_address(self):
        """
        Gets the customer_shipping_address of this UpdateApplianceExportJobDetails.

        :return: The customer_shipping_address of this UpdateApplianceExportJobDetails.
        :rtype: ShippingAddress
        """
        return self._customer_shipping_address

    @customer_shipping_address.setter
    def customer_shipping_address(self, customer_shipping_address):
        """
        Sets the customer_shipping_address of this UpdateApplianceExportJobDetails.

        :param customer_shipping_address: The customer_shipping_address of this UpdateApplianceExportJobDetails.
        :type: ShippingAddress
        """
        self._customer_shipping_address = customer_shipping_address

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateApplianceExportJobDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateApplianceExportJobDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateApplianceExportJobDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateApplianceExportJobDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateApplianceExportJobDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateApplianceExportJobDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateApplianceExportJobDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateApplianceExportJobDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from oci._vendor.requests.exceptions import RequestException as BaseRequestException
from oci._vendor.requests.exceptions import ConnectTimeout as BaseConnectTimeout


class ServiceError(Exception):
    """The service returned an error response."""

    def __init__(self, status, code, headers, message, **kwargs):
        self.status = status
        self.code = code
        self.headers = headers
        self.message = message
        self.original_request = kwargs.get('original_request')
        self.request_id = self._get_opc_request_id()

        if not message:
            message = "The service returned error code %s" % self.status

        super(ServiceError, self).__init__({
            "opc-request-id": self.request_id,
            "code": code,
            "message": message,
            "status": status
        })

    def _get_opc_request_id(self):
        if self.headers.get("opc-request-id"):
            return self.headers.get("opc-request-id")
        elif self.original_request and self.original_request.header_params:
            return self.original_request.header_params.get("opc-request-id")
        else:
            return None


class ClientError(Exception):
    """A client-side error occurred.."""


class ConfigFileNotFound(ClientError):
    """Config file not be found."""


class InvalidConfig(ClientError):
    """The config object is missing required keys or contains malformed values.

    For example:

    .. code-block:: python

        raise InvalidConfig({
            "region": "missing",
            "key_id": "malformed'
        })
    """
    def __init__(self, errors):
        """:param errors: {config key: error code}"""
        self.errors = errors

    def __str__(self):
        return str(self.errors)


class InvalidPrivateKey(ClientError):
    """The provided key is not a private key, or the provided passphrase is incorrect."""


class MissingPrivateKeyPassphrase(InvalidPrivateKey):
    """The provided key requires a passphrase."""


class ProfileNotFound(ClientError):
    """The specified profile was not found in the config file."""


class WaitUntilNotSupported(ClientError):
    """wait_until is not supported by this response."""


class MaximumWaitTimeExceeded(ClientError):
    """Maximum wait time has been exceeded."""


class MultipartUploadError(Exception):
    """
    Exception thrown when an error with a multipart upload occurs. As multipart uploads can be
    parallelised, this error contains a collection of errors which caused individual part uploads
    to fail
    """
    def __init__(self, **kwargs):
        """
        :param queue error_causes_queue:
            A queue containing errors which occured during the multipart upload
        """
        self.error_causes = []
        if 'error_causes_queue' in kwargs:
            while not kwargs['error_causes_queue'].empty():
                self.error_causes.append(kwargs['error_causes_queue'].get())


class CompositeOperationError(Exception):
    """
    An exception occurred during a composite operation (e.g. launching an instance and waiting for state)
    but part of the composite operation succeeded. This exception has the following attributes:

    :var list partial_results: Any partial results which are available (e.g. if the :py:meth:`~oci.core.ComputeClient.launch_instance` succeeded and the waiting for state failed then this will contain the :py:meth:`~oci.core.ComputeClient.launch_instance` result)
    :var Exception cause: The exception which caused the composite operation to fail
    """

    def __init__(self, partial_results=[], cause=None):
        self.partial_results = partial_results
        self.cause = cause


class RequestException(BaseRequestException):
    """An exception occurred when making the request"""


class ConnectTimeout(BaseConnectTimeout):
    """The request timed out while trying to connect to the remote server.

    Requests that produced this error are safe to retry.
    """


class MissingEndpointForNonRegionalServiceClientError(ValueError):
    """No endpoint value was provided when trying to create a non-regional service client.
    """
